* Figure 2. Show Up Rates Versus Log Per Capita Consumption
* Figure 3. Show Up Rates Versus Observable and Unobservable Components of Log Per Capita Consumption

* Note: the fanreg command must be installed, and STATA must be running with administrator rights
* http://eml.berkeley.edu/~webfac/emiguel/e270c_s09/ps1.ado.txt

clear all
pause off
set more off

set seed 2438279
set sortseed 10000

local STfolder = "$STfolder"
cd "`STfolder'"

***

use "data\codeddata\baseline\matched_baseline.dta",clear
keep if selftargeting==1 /*this analysis is only on selftargeting households*/

set seed 100

*** Figure 2

quietly fanreg showup logconsumption,reps(500) bw(5) np(50) xgen ("temp1") ygen("showup_obs") maxminon max(0.8) min(0) cluster(hhea)

twoway (line showup_obs   temp1, sort) ///
       (line showup_obs_u temp1, sort graphregion(color(white)) clpat(dash) col(blue)) ///
       (line showup_obs_l temp1, sort clpat(dash) col(blue)), legend(off) ///
	   xtitle("Log Consumption") ytitle("Show-up Probability")
graph save Graph "figures\Figure 2.gph",replace
graph export     "figures\Figure 2.eps", replace

drop temp1 showup_obs showup_obs_u showup_obs_l



*** FIGURE 3a 

* find where to draw vertical line - average cutoff (using baseline data)
 gen log3 = log(povertyline3)
 sum log3

set seed 100

quietly fanreg showup PMTSCORE, reps(500) bw(5) np(50) xgen ("temp1") ygen("showup_obs") maxminon max(0.8) min(0) cluster(hhea)

twoway (line showup_obs    temp1, sort) ///
	   (line showup_obs_u  temp1, sort graphregion(color(white)) clpat(dash) col(blue)) ///
	   (line  showup_obs_l temp1, sort clpat(dash) col(blue)), ///
	   legend(off) xtitle("Observable Component of Log Consumption (PMT score)") ytitle("Show-up Probability") xline(12.26)
	   
graph save Graph "figures\Figure 3a.gph", replace
graph export     "figures\Figure 3a.eps", replace

drop temp1 showup_obs showup_obs_u showup_obs_l



*** FIGURE 3b

*generating unobservable := logc - PMTSCORE (in regression sense)
reg       logconsumption PMTSCORE, cl(hhea)
predict p_logconsumption
gen     logc_u = logconsumption-p_logconsumption
drop    p_logconsumption

*graph

set seed 100

quietly fanreg showup logc_u, reps(500) bw(5) np(50) xgen ("temp1") ygen("showup_unobs") maxminon max(0.8) min(0) cluster(hhea)

twoway (line  showup_unobs   temp1, sort) ///
	   (line  showup_unobs_u temp1, sort graphregion(color(white)) clpat(dash) col(blue)) ///
	   (line  showup_unobs_l temp1, sort clpat(dash) col(blue)), ///
	   legend(off) xtitle("Unobservable Component of Log Consumption") ytitle("Show-up Probability") /*yscale(range(-0.2 0.8)) ylabel(-0.2(0.2)0.8)*/

graph save Graph  "figures\Figure 3b.gph", replace
graph export      "figures\Figure 3b.eps", replace
