* Online Appendix Figure 1 Break-even discount factor

* Note: the fanreg command must be installed, and STATA must be running with administrator rights
* http://eml.berkeley.edu/~webfac/emiguel/e270c_s09/ps1.ado.txt

clear all
pause off
set more off

set seed 345789
set sortseed 10000

local STfolder = "$STfolder"
cd "`STfolder'"

***

**** Get Data/Prep Variables

* get costs to apply (no both-spouse adjustment)
	u "data\codeddata\midline\costs.dta", clear		
	keep if maintreatment==2 
	
	keep hhid totcost_pc hhsize benefit hh_benefit_mly
	rename hh_benefit_mly hh_benefit
	tempfile costs
	save	`costs'

* household head age
	use "data/codeddata\baseline\hhhead.dta"
	keep hhid hhage
	tempfile HHhead
	save	`HHhead'

* Merging
	use "data/codeddata\baseline\matched_baseline.dta", clear

	merge 1:1 hhid using `costs'
	assert _m!=2
	keep if _m==3
	drop _m

	merge 1:1 hhid using `HHhead'
	assert _merge!=1
	keep if _merge==3
	drop _merge

* Needed Variables
	gen singlehead=0
	replace singlehead=1 if hhsize==1 & hhage>=16 & hhage<=65

	rename benefit original_benefits
	gen benefits=original_benefits/1000000
	la var original_benefits "original value of benefits"
	la var benefits "normalized by 1 million"

**** Generate discount factor
local control "hhsize educationhhhead children0to3 children4to5 children6to12 children13to15 hhmale hhwidow"
local control_1 "singlehead benefits"
local control_2 "singlehead children0to3 children4to5 children6to12 children13to15 benefits"


*** Probit of getbenefit on log consumption
	gen belowpovertyline=(pcexppred<=povertyline3)      

	probit  belowpovertyline logconsumption
	predict pass_predict_probit

*** Compute discount factor (overall)
* discount_breakeven_probit = d + d^2 + ... + d^6

	gen discount_breakeven_probit = (totcost_pc*hhsize)                 /// total cost paid by households
								   /(pass_predict_probit*hh_benefit*12) // annual benefit

* Local linear regression of showup on consumption
	set seed 100
	quietly fanreg showup logconsumption, reps(50) bw(5) np(100) xgen("x") ygen("y") cluster(hhea)

* Local linear regression of (overall) discount factor on consumption
	set seed 100
	quietly fanreg discount_breakeven_probit logconsumption, reps(50) bw(5) np(100) xgen("xtemp") ygen("ytemp") maxminon max(50) min(0) cluster(hhea)

* Convert from overall discount factor to yearly discount factor
	cap drop delta_y*
	gen delta_ytemp=.
	gen delta_ytemp_u=.
	gen delta_ytemp_l=.

	count
	local N=_N
	local step = 0.001
	local tol  = 0.001

	foreach va in ytemp ytemp_u ytemp_l {
		forv i=1/101{
			if(`va'[`i']!=.){
				di 	`i'
				local delta = 0
				local Y = 0

				while(`Y'<`va'[`i'] & `delta'<1.5){
					local delta = `delta' + `step'
					local Y     = `delta'+`delta'^2+`delta'^3+`delta'^4+`delta'^5+`delta'^6
				}
				if(`delta'<1.5){
					replace delta_`va' = `delta' in `i'
				}
			}	
		}
	}

* make sure it worked
	cap drop new_ytemp*
	pause on
	foreach va in ytemp ytemp_u ytemp_l {
		gen new_`va' = delta_`va'+delta_`va'^2+delta_`va'^3+delta_`va'^4+delta_`va'^5+delta_`va'^6
		noi reg new_`va' `va'
		pause coefficient very close to 1?
	}
 
 **** Figure
twoway (hist logconsumption, w(0.1) fcolor(ltblue) lcolor(ltblue) fintensity(inten10)) ///
	   (line y x,sort col(green)) ///
       (line delta_ytemp   xtemp if delta_ytemp<=1  , sort col(blue)) ///
	   (line delta_ytemp_u xtemp if delta_ytemp_u<=1, sort clpat(dot) col(blue)) ///
	   (line delta_ytemp_l xtemp if delta_ytemp_l<=1, sort clpat(dot) col(blue)) ///
	   (line delta_ytemp   xtemp if delta_ytemp>=1   & delta_ytemp<=1.5 , sort col(red) clpat(dash)) ///
	   (line delta_ytemp_u xtemp if delta_ytemp_u>=1 & delta_ytemp_u<=1.5, sort clpat(dot) col(red)) ///
	   (line delta_ytemp_l xtemp if delta_ytemp_l>=1 & delta_ytemp_l<=1.5, sort clpat(dot) col(red)) ///
	   , xtitle("log per capita consumption") ytitle("break even discount factor") legend(off) ///
	   graphregion(color(white)) bgcolor(white)

graph export "figures\Online Appendix Figure C1.png",replace
graph export "figures\Online Appendix Figure C1.eps",replace
