* Online Appendix Figure C.2 Comparison between Government and Baseline Data

/*
Notation:

ST = self targeting
AE = automatic enrollment 
HUAE = hypothetical universal EA

1 - uses govt data
2 - uses mixed data (govt data on those who show up, baseline data on the rest)
3 - uses baseline data on everyone
*/

clear all
pause on
set more off

set seed 345789
set sortseed 10000

local STfolder = "$STfolder"
cd "`STfolder'"

***

**** Get Data
use "data\codeddata\baseline\matched_baseline.dta",clear

**** Find optimal noise level 

*** noise up the baseline PMT 
sum PMTSCORE
		
tempfile tempdata
save 	`tempdata'

forv i=1/4{

	use `tempdata', clear
	
	local  var: word `i' of excl_error 			incl_error 			mistarget 		logc 
	local name: word `i' of "Exclusion Error" 	"Inclusion Error" 	"Mistargeting" 	"Log Consumption"
		
		gen sd=.
		gen `var'_original=.
		gen `var'_sd=.
		
		forv sd=0(0.01)1{
			local index = round(`sd'*100)
			
			gen noise_`index' = rnormal(0,`sd')
			gen PMTSCORE_`index' = PMTSCORE + noise_`index'
			gen pcexppred_`index' = exp(PMTSCORE_`index')
			
			gen povertyline3_`index'=.

			*** one line per region
			forv prov=1/3{
			forv urba=0/1{

			qui sum povertyline3_pctile if prov==`prov' & urban==`urba'
			local pctile = r(mean)

			cap drop temp
			egen temp = pctile(pcexppred_`index')  if prov==`prov' & urban==`urba', p(`pctile')		
			replace povertyline3_`index' = temp    if prov==`prov' & urban==`urba'
			}
			}
			
			gen getbenefit_`index' = pcexppred_`index' < povertyline3_`index'
			drop povertyline3_`index' PMTSCORE_`index' pcexppred_`index'
		}
		
		keep if selftargeting == 0  & showup == 1	
		
		forv sd=0(0.01)1{
			local index = round(`sd'*100)
			local indexp1 = round(`sd'*100)+1
		
			*generate errors for `sd' beneficiaries
			gen     excl_error_`index'=0 if verypoor_povertyline1==1 & getbenefit_`index'==1
			replace excl_error_`index'=1 if verypoor_povertyline1==1 & getbenefit_`index'==0

			gen     incl_error_`index'=0 if  verypoor_povertyline1==0 & getbenefit_`index'==0
			replace incl_error_`index'=1 if  verypoor_povertyline1==0 & getbenefit_`index'==1

			gen     mistarget_`index' = excl_error_`index'
			replace mistarget_`index' = incl_error_`index' if mistarget_`index'==.
			
			replace sd = `sd' in `indexp1'
			
			if("`var'"=="logc"){
				qui sum logconsumption if getbenefit_`index'==1
				replace logc_sd = r(mean) in `indexp1' 
				
				qui sum logconsumption if getbenefit==1
				replace logc_original = r(mean) in `indexp1' 
			}
			else{
				qui sum `var'_`index'
				replace `var'_sd = r(mean) in `indexp1'
				
				qui sum `var'
				replace `var'_original = r(mean) in `indexp1'
			}
			
		}
		
		lpoly `var'_sd sd, bw(0.076) nograph gen(`var'_sd_lpoly) at(sd)
		
		label variable sd "Noise Standard Deviation"
		label variable `var'_original "`name' (government data)"
		label variable `var'_sd       "`name' (baseline data)"
		label variable `var'_sd_lpoly "`name' (baseline data, smoothed)"
		
		twoway (line  `var'_original sd, xlabel(0(0.1)1) color(black) lpattern(dash)) /// 
		       (scatter `var'_sd sd) ///
		       (line `var'_sd_lpoly sd), legend(cols(1)) ytitle("`name'")
		graph export "figures\Online Appendix Figure C2_`var'.eps", replace
		
}

