* Online Appendix Figure C.4 Model Fit and Counterfactuals
* Quintile plots of showup and predicted showup *

* ssc install grc1leg

clear all
pause on
set more off

set seed 345789
set sortseed 10000

local STfolder = "$STfolder"
cd "`STfolder'"

**************
* Input data
**************

insheet using "data\codeddata\matlab\MATLAB_showuphat.csv", comma clear	
tostring hhid, replace
	forv x = 1/5 {
		replace hhid = "0"+hhid if length(hhid)<6
		}
	g hhea = substr(hhid,1,3)
	
merge 1:1 hhid using "data\codeddata\baseline\matched_baseline.dta"
assert _m!=1
keep if _m==3
drop _m


**************
* Re-code
**************

rename closesubtreatment close
collapse showup*, by(quant_idx close)

set scheme s1color

reshape wide showup*, i(quant_idx) j(close)
la var quant_idx "Consumption Quintile"

foreach v of varlist showup*0 {
	la var `v' "Far"
}
foreach v of varlist showup*1 {
	la var `v' "Close"
}

**************
* Individual graphs
**************

* measured
tw (line showup1 quant_idx, color(black) lwidth(thick)) (line showup0 quant_idx, color(orange) lwidth(thick)), name(showup, replace) subtitle( "Measured Rates") nodraw 

* actual cost
tw (line showup_hat1 quant_idx, color(black) lwidth(thick)) (line showup_hat0 quant_idx, color(orange) lwidth(thick)), name(showup_hat, replace) subtitle( "Baseline Model") nodraw 

* no diff travel cost
tw (line showup_hat_smthc1 quant_idx, color(black) lwidth(thick)) (line showup_hat_smthc0 quant_idx, color(orange) lwidth(thick)), name(showup_hat_smthc, replace) subtitle( "Same Travel Technology") nodraw 

* Inflated Cost Graphs
forvalues i = 3(3)6 {
	tw (line showup_hat_km`i'1 quant_idx, color(black) lwidth(thick)) (line showup_hat_km`i'0 quant_idx, color(orange) lwidth(thick)), name(showup_hat_km`i', replace) subtitle( "Travel Distance + `i'km") nodraw 
	tw (line showup_hat_`i'aw1 quant_idx, color(black) lwidth(thick)) (line showup_hat_`i'aw0 quant_idx, color(orange) lwidth(thick)), name(showup_hat_`i'aw, replace) subtitle( "Average Wait * `i'") nodraw 
}

* alpha =0 and =1
tw (line showup_hat_alpha01 quant_idx, color(black) lwidth(thick)) (line showup_hat_alpha00 quant_idx, color(orange) lwidth(thick)), name(showup_hat_a0, replace) subtitle( "Alpha=0") nodraw 
tw (line showup_hat_alpha11 quant_idx, color(black) lwidth(thick)) (line showup_hat_alpha10 quant_idx, color(orange) lwidth(thick)), name(showup_hat_a1, replace) subtitle( "Alpha=1") nodraw 


**************
* Combine graphs for main 9-panel figure
**************

* combine
//grc1leg showup_hat showup_hat_a0 showup_hat_a1  , xsize(7) ysize(3.3) subtitle("Predicted Showup") name(combine4,replace) row(1) ycommon legend(showup_hat)
grc1leg showup_hat showup_hat_km3 showup_hat_km6, xsize(7) ysize(3.3) subtitle("Predicted Show Up (Model)") name(combine2,replace) row(1) ycommon legend(showup_hat)
grc1leg showup_hat showup_hat_3aw showup_hat_6aw, xsize(7) ysize(3.3) subtitle("Predicted Show Up (Model)") name(combine3,replace) row(1) ycommon legend(showup_hat)

grc1leg showup showup_hat showup_hat_smthc, xsize(7) ysize(3.3) name(combine1,replace) row(1) ycommon  subtitle( "         Show Up (Experimental)            Predicted Show Up (Model)               ") legend(showup_hat)
grc1leg combine1 combine2 combine3 /*combine4*/, rows(3) legend(combine1) name(combine,replace)
* aspect ratio
gr_edit .style.editstyle aspect_pos(north) editcopy
gr_edit .style.editstyle declared_ysize(9.9) editcopy
gr_edit .style.editstyle declared_xsize(7) editcopy
* legend
gr_edit .legend.Edit, style(key_ysize(vsmall)) style(key_xsize(9)) keepstyles 
gr_edit .legend.Edit, style(labelstyle(size(vsmall)))
* save
gr save   "figures/Online Appendix Figure C4", replace 
gr export "figures/Online Appendix Figure C4.eps", name(combine) as(eps) replace
gr export "figures/Online Appendix Figure C4.tif", name(combine) replace
