* Online Appendix Table C.1. Experiment Validation

clear all
pause on
set more off

set seed 345789
set sortseed 10000
set matsize 800

local STfolder = "$STfolder"
cd "`STfolder'"

***

**** GET DATA/PREP VARIABLES

* average distance to kecamatan
use "data\originaldata\precoded\distances.dta", clear
keep hhea distance_kec
collapse (mean) distance_kec, by(hhea)

tempfile dist
save	`dist'
	
* Merge with baseline data

use "data\codeddata\baseline\hhhead.dta", clear

merge 1:1 hhid using "data\codeddata\baseline\coding_suseti_pmt.dta"
recode  educationhhhead (95 98=.)
assert _merge==3
drop _merge

merge 1:1 hhid using "data\codeddata\baseline\consumption.dta"
assert _merge==3
drop _merge

collapse (mean) logconsumption consumption yreducationhhhead PMTSCORE , by( hhea)

merge 1:1 hhea using "data\codeddata\baseline\rthead.dta"
assert _merge==3
drop _merge

merge 1:1 hhea using `dist'
assert _merge==3
drop _merge

merge 1:1 hhea using "data\codeddata\baseline\pctagriculture.dta"
assert _merge==3
drop _merge

merge 1:1 hhea using "data\originaldata\other\randomization.dta"
assert _m==3
drop   _m

merge 1:1 hhea using "data\originaldata\precoded\coding_podes08.dta"
assert _m==3
drop _m

* Variables for Table

keep hhea logconsumption PMTSCORE yreducationhhhead pctagriculturalhh yreducationrthead tothhinRT selftargeting hybrid kecagroup distance logvillagesize religiousbuildingperhh primaryschperhh
sum

gen lognumberhh=log(tothhinRT)
compress
sort hhea

rename pctagriculturalhh pctagriculture

cap erase "tables\Online Appendix Table C1*.*"

* Drop Hybrid Households
/*We are only interested in selftargeting and PMT. So drop all households from hybrid treatment.*/

drop if hybrid==1
gen PMT=(selftargeting==0)
rename selftargeting ST

**** Create Table

local var_list "logconsumption yreducationhhhead PMTSCORE pctagriculture yreducationrthead lognumberhh distance_kec logvillagesize religiousbuildingperhh primaryschperhh"

** Columns 1 & 2 (Mean)
foreach i in PMT ST{
	gen varname`i'=""
	gen mean`i'=.
	gen sd`i'=.
	local count`i'=1
	
	foreach x in `var_list'{
		sum `x' if `i'==1
		replace varname`i'="`x'" in `count`i''
		replace mean`i'=r(mean) in `count`i''
		replace sd`i'=r(sd) in `count`i''
		local count`i'=`count`i''+1
	}

}
order    varnamePMT meanPMT sdPMT varnameST meanST sdST
outsheet varnamePMT meanPMT sdPMT varnameST meanST sdST using "tables/Online Appendix Table C1 means.csv", nolabel replace comma
drop varname* mean* sd*



local var_num=1

** Column 3 (No Fixed Effect)
foreach x in `var_list'{
	qui reg `x' ST, cluster(hhea)
	
	if(`var_num'==1){
		outreg2 ST using "tables\Online Appendix Table C1 diff noFE", excel paren(se) bdec(3) replace nocons nor2
	}
	else{
		outreg2 ST using "tables\Online Appendix Table C1 diff noFE", excel paren(se) bdec(3) append nocons nor2
	}
	
	qui reg `x' ST
	estimates store var`var_num'
	qui su `x' if ST==1
	local sd`var_num' = r(sd)
	local var_num = `var_num'+1
}

* Joint test (No Fixed Effect)
suest var1 var2 var3 var4 var5 var6 var7 var8 var9 var10 , cluster(hhea)

forv x = 1/9 {
test _b[var`x'_mean: ST] = 0, notest accum
}
test _b[var10_mean: ST] = 0, accum

gen joint_title = "Chi2" in 1
replace joint_title = "P-Value" in 2
gen joint_nofe = r(chi2) in 1 
replace joint_nofe = r(p) in 2

local var_num=1

** Column 4 (With Fixed Effect)
foreach x in `var_list'{
	qui xi: reg `x' ST i.kecagroup, cl(hhea)
	
	if(`var_num'==1){
		outreg2 ST using "tables\Online Appendix Table C1 diff FE", excel paren(se) bdec(3) replace nocons nor2
	}
	else{
		outreg2 ST using "tables\Online Appendix Table C1 diff FE", excel paren(se) bdec(3) append nocons nor2
	}
	qui xi: reg `x' ST i.kecagroup
	estimates store var`var_num'
	qui su `x' if ST==1
	local sd`var_num' = r(sd)
	local var_num = `var_num'+1
}

*Joint Test (With Fixed Effect)
suest var1 var2 var3 var4 var5 var6 var7 var8 var9 var10, cluster(hhea)

forv x = 1/9 {
test _b[var`x'_mean: ST] = 0, notest accum
}
test _b[var10_mean: ST] = 0, accum

gen joint_fe = r(chi2) in 1 
replace joint_fe = r(p) in 2

outsheet joint* in 1/2 using "tables\Online Appendix Table C1 joint test.csv", replace comma

