* Online Appendix Table C.18 Summary Statistics of Modeled Registration Costs

clear all
pause on
set more off

set seed 345789
set sortseed 10000

local STfolder = "$STfolder"
cd "`STfolder'"

***

**** Get Data/Prep Variables
* costs calculated without the both-spouse adjustment
	u "data\codeddata\midline\costs.dta", clear		

* Calculate total cost per capita with inflated weight time (3x and 6x)
	g totcost_3aw_pc = totcost_pc + (2*ave_waiting*wagerate)/(hhsize*60)
	g totcost_6aw_pc = totcost_pc + (5*ave_waiting*wagerate)/(hhsize*60)

**** Total Cost Per Capita table

* table prep
gen cost_close=. //close subtreatment
gen cost_far  =. //far subtreatment
gen cost_smth =. //assuming safe travel technology (far)
gen cost_3k   =. //distance + 3km (far)
gen cost_6k   =. //distance + 6km (far)
gen cost_3aw  =. //wait time*3 (far)
gen cost_6aw  =. //wait time*6 (far)

* total cost
	sum totcost_pc if closesubtreatment==1
	replace cost_close = r(mean) in 1

	sum totcost_pc if closesubtreatment==0
	replace cost_far = r(mean) in 1

	foreach suffix in "smth" "3k" "6k" "3aw" "6aw"{
		sum totcost_`suffix'_pc if closesubtreatment==0
		replace cost_`suffix' = r(mean) in 1
	}

* distance to site
	sum distance_rep if closesubtreatment==1
	replace cost_close = r(mean) in 2

	sum distance_rep if closesubtreatment==0
	replace cost_far = r(mean) in 2
	replace cost_smth= r(mean) in 2
	replace cost_3k  = r(mean)+3 in 2
	replace cost_6k  = r(mean)+6 in 2
	replace cost_3aw = r(mean) in 2
	replace cost_6aw = r(mean) in 2

* wait time
	sum ave_waiting if closesubtreatment==1
	replace cost_close = r(mean) in 3

	sum ave_waiting if closesubtreatment==0
	replace cost_far = r(mean) in 3
	replace cost_smth= r(mean) in 3
	replace cost_3k  = r(mean) in 3
	replace cost_6k  = r(mean) in 3
	replace cost_3aw = r(mean)*3 in 3
	replace cost_6aw = r(mean)*6 in 3
	

outsheet cost_* in 1/3 using "tables\Online Appendix Table C18.csv", replace comma

