* Online Appendix Table C.7. Factors interacted with Self-Targeting treatment predicting benefit receipt (Logit)

clear all
pause on
set more off

set seed 345789
set sortseed 10000

local STfolder = "$STfolder"
cd "`STfolder'"

***

**** Get Data/Prep Variables

*** Groups and times
	u "data/originaldata/Baseline/hh_pm2.dta", clear
	bys hhid: egen numactivities = max(pm03_line)
	bys hhid: egen activityhours = total(pm05)
	keep hhid numactivities activityhours
	duplicates drop
	tempfile activities
	sa `activities'


*** Education level
	u "data/originaldata/Baseline/hh_krt.dta"
	keep hhid krt05 krt08*
	replace krt05 = 0 if krt05==3
	recode krt08x (95=0) (98=.)
	ren krt05 HH_head_canread
	ren krt08x HH_head_borninvill
	ren krt08 HH_yrs_since_moved_in
	replace HH_yrs_since_moved_in = 100 if HH_yrs_since_moved_in==. & HH_head_bornin==1
	tempfile hhhead
	sa `hhhead'

*** Other benefits
	u "data/originaldata/baseline/hh_ksr1.dta", clear
	recode ksr01 (3=0)
	drop ksr01a ksr01ax
	reshape wide ksr01, i(hhid) j(ksr1type) string
	ren ksr01a askeskin
	ren ksr01b raskin
	ren ksr01c blt
	tempfile benefits
	sa `benefits'

*** Shocks
	u "data/originaldata/baseline/hh_ge.dta", clear
	g shocks = ge01==1
	collapse (sum) shocks, by(hhid)
	tempfile shocks
	sa `shocks'


*** Subjective welfare
	u "data/originaldata/baseline/hh_sw.dta", clear
	recode sw02 (8=.)
	recode sw03 (7=.)
	ren sw01 happiness
	ren sw02 selfwealth
	ren sw03 selfcompwealth
	tempfile subj
	sa `subj'

*** Widow, sector, and highest ed achieved
	u "data/originaldata/baseline/hh_ar2.dta", clear
	keep if ar00==1
	keep hhid ar03 ar06 ar08 ar17 ar18
	* Widow
	g widow=ar06==4&ar03==3
	drop ar03 ar06
	* Sector
	g sect_agriculture = ar08==1
	g sect_plantation = ar08==2
	g sect_livestock = ar08==3
	g sect_fisheries = ar08==4
	g sect_hunting = ar08==5
	g sect_mining = ar08==6
	g sect_manufacturing = ar08==7
	g sect_utilities = ar08==8
	g sect_ctruction = ar08==9
	g sect_service_sales = ar08==10
	g sect_transportation = ar08==11
	g sect_financial_services = ar08==12
	g sect_social_services = ar08==13
	g sect_look_after_hh = ar08==14
	g sect_other = ar08==95
	drop sect_other
	drop ar08
	* Education level
	g yearsed = 0 if ar17==0
	replace yearsed = ar18 if ar18>=1 & ar18<=6
	replace yearsed = 6 if (ar17==2 | ar17==5) & yearsed==.
	replace yearsed = 9 if ar17==3 | ar17==6
	replace yearsed = 12 if ar17==4 | ar17==7
	replace yearsed = 14 if ar17==8
	replace yearsed = 16 if ar17==9
	replace yearsed = 18 if ar17==10
	drop ar17 ar18
	tempfile sector
	sa `sector'

*** Epsilon
	use "data/codeddata\baseline\matched_baseline.dta", clear
//keep if maintreatment==2

*generate epsilon=logconsumption-PMTSCORE
	reg logconsumption PMTSCORE, cl(hhea)
	predict p_logconsumption
	gen epsilon=logconsumption-p_logconsumption

*** Merge data

merge 1:1 hhid using `activities'
drop if _m==2
drop _m

merge 1:1 hhid using `hhhead'
assert _m!=1
drop if _m==2
drop _m
merge 1:1 hhid using `benefits'
assert _m!=1
drop if _m==2
drop _m
merge 1:1 hhid using `shocks'
assert _m!=1
drop if _m==2
drop _m
merge 1:1 hhid using `subj'
assert _m!=1
drop if _m==2
drop _m
merge 1:1 hhid using `sector'
assert _m!=1
drop if _m==2
drop _m

replace numactivities = 0 if numactivities==.
replace activityhours = 0 if activityhours==.


*** Generate Interactions
foreach va in PMTSCORE epsilon numactivities activityhours raskin askeskin blt selfwealth shocks widow yearsed{
gen `va'_t = `va' * selftargeting
}

order PMTSCORE PMTSCORE_t epsilon epsilon_t numactivities numactivities_t ///
      activityhours activityhours_t raskin raskin_t askeskin askeskin_t blt blt_t ///
	  selfwealth selfwealth_t shocks shocks_t widow widow_t yearsed yearsed_t

tempfile data
sa `data'

**** Create Table

local depvar /*excl_error  incl_error showup */ getbenefit

local x = 1	
local a : word `x' of OLS_A OLS_B
local b : word `x' of Logit_A Logit_B

*** Regressions: OLS (Not in appendix)
cap erase "`outfolder'`depvar'Regs_`a'.xml"
cap erase "`outfolder'`depvar'Regs_`a'.txt"

forv y=1/6{

local regressors: word `y' of ///
"PMTSCORE* epsilon* selfwealth*" ///								
"PMTSCORE* epsilon* numactivities* activityhours*" ///
"PMTSCORE* epsilon* shocks*" ///
"PMTSCORE* epsilon* widow*" ///
"PMTSCORE* epsilon* yearsed*" ///
"PMTSCORE* epsilon* selfwealth* numactivities* activityhours* shocks* widow* yearsed*"

qui reg `depvar' `regressors', cl(hhea)
qui sum `depvar' if e(sample)
local m1 = `r(mean)'
outreg2 *_t using "tables\Online Appendix Table C7_`a'",excel se bdec(3) addstat("mean of dep var", `m1', "Adjusted R-Squared", `e(r2_a)')  append ///
       groupvar(PMTSCORE_t epsilon_t selfwealth_t  numactivities_t  activityhours_t   shocks_t widow_t  yearsed_t)
}


*** Regressions: logit (Appendix table C7)
cap erase "`outfolder'`depvar'Regs_`b'.xml"
cap erase "`outfolder'`depvar'Regs_`b'.txt"

forv y=1/6{

local regressors: word `y' of ///
"PMTSCORE* epsilon* selfwealth*" ///								
"PMTSCORE* epsilon* numactivities* activityhours*" ///
"PMTSCORE* epsilon* shocks*" ///
"PMTSCORE* epsilon* widow*" ///
"PMTSCORE* epsilon* yearsed*" ///
"PMTSCORE* epsilon* selfwealth* numactivities* activityhours* shocks* widow* yearsed*"

version 10: logit `depvar' `regressors', cl(hhea)
qui sum `depvar' if e(sample)
local m1 = `r(mean)'
outreg2 *_t using "tables\Online Appendix Table C7_`b'", excel se bdec(3) addstat("mean of dep var", `m1') append ///
groupvar( PMTSCORE_t  epsilon_t  selfwealth_t  numactivities_t  activityhours_t  shocks_t  widow_t  yearsed_t)

di "STEP `y': `regressors'"
}



