*** Appendix Tables C9-C13 
*** ST vs HUAE variations for the appendix
/*
Notation:

ST = self targeting
AE = automatic enrollment 
HUAE = hypothetical universal EA

1 - use govt data
2 - use mixed data (govt data on those who show up, baseline data on the rest)
3 - use baseline data on everyone
*/

clear all
pause on
set more off

* used to make outreg2 output look nicer
prog drop _all
prog define eqmatch
 syntax anything
 gettoken one two: anything
 local one=trim("`one'")
 local two=trim("`two'")
 split varname, parse(":") gen(_varname)
 replace eqname="`one'" if eqname=="`two'"
 replace report=/*eqname+":"+*/_varname2
end

set seed 345789
set sortseed 10000

local STfolder = "$STfolder"
cd "`STfolder'"

***

/* 
1 - Online Appendix Table C9
2 - Online Appendix Table C10
3 - Online Appendix Table C11
4 - Online Appendix Table C13
5 - Online Appendix Table C12
*/
forv table=1/5{

local name : word `table' of "9" 	"10" 	 "11" 	  "13" 		"12"		// table name
local name1: word `table' of "s3huae3_npv_noise_ols" "st3huae3_opv_noise_logit" "st1huae2_npv_noise_logit" "st1huae2_npv_0noise_logit" "st3huae3_npv_0noise_logit"
local cmd1 : word `table' of "reg"  "logit"  "logit"  "logit"  	"logit"    	// command name   w/o fe
local cmd2 : word `table' of "areg" "clogit" "clogit" "clogit" 	"clogit"  	// command name   w   fe
local suf2 : word `table' of "ab"   "group"  "group"  "group" 	"group"		// command suffix w   fe
local cnam : word `table' of "ols"  "logit"  "logit"  "logit" 	"logit"		// command name 

use "data\codeddata\baseline\matched_baseline.dta", clear

**** Prep Variables
*generate corresponding getbenefit_hypothetical foreach table
if(`table'==1){	
	*** ST3 versus HUAE3 using new poverty line and noisy PMT
	gen     getbenefit_hypothetical = (pcexppred_noise<povertyline3_noise)
	replace getbenefit_hypothetical = 0 if showup==0 & selftargeting==1
	
}
else if(`table'==2){
	*** ST3 versus HUAE3 using govt poverty line and noisy PMT
	gen     getbenefit_hypothetical = (pcexppred_noise<povertyline2)
	replace getbenefit_hypothetical = 0 if showup==0 & selftargeting==1	
	
}	
else if(`table'==3){	
	*** ST1 versus HUAE2 using new poverty line and noisy PMT
	gen     getbenefit_hypothetical = getbenefit
	replace getbenefit_hypothetical = (pcexppred_noise<povertyline3_noise)  if showup==0 & selftargeting==0

}
else if(`table'==4){
	*** ST1 versus HUAE2 using new poverty line, NO noise
	gen     getbenefit_hypothetical = getbenefit
	replace getbenefit_hypothetical = (pcexppred<povertyline3)  if showup==0 & selftargeting==0
	
}
else if(`table'==5){
	*** ST3 versus HUAE3 using new povertyline, NO noise
	gen     getbenefit_hypothetical = (pcexppred<povertyline3)
	replace getbenefit_hypothetical = 0 if showup==0 & selftargeting==1
}

*generate errors for hypothetical beneficiaries
gen     excl_error_hypothetical=0 if verypoor_povertyline1==1 & getbenefit_hypothetical==1
replace excl_error_hypothetical=1 if verypoor_povertyline1==1 & getbenefit_hypothetical==0

gen     incl_error_hypothetical=0 if  verypoor_povertyline1==0 & getbenefit_hypothetical==0
replace incl_error_hypothetical=1 if  verypoor_povertyline1==0 & getbenefit_hypothetical==1

gen     mistarget_hypothetical = excl_error_hypothetical
replace mistarget_hypothetical = incl_error_hypothetical if mistarget_hypothetical==.

tab excl_error_hypothetical, missing
tab incl_error_hypothetical, missing
tab  mistarget_hypothetical, missing

*generate interaction terms
gen logc_ST = logconsumption * selftargeting

**** Regressions
*** No Stratum FEs
{
reg logconsumption selftargeting if getbenefit_hypothetical==1, cl(hhea)
qui summ logconsumption if e(sample)
local m = r(mean)
outreg2 selftargeting using "tables\Online Appendix Table C`name'", ///
nocons nor excel eq(auto) se bdec(3) addstat("mean of dep var",`m') replace /*eq(auto)*/

`cmd1' getbenefit_hypothetical selftargeting logconsumption logc_ST,  cl(kecagroup)
qui summ getbenefit_hypothetical if e(sample)
local m1 = r(mean)
outreg2 selftargeting logconsumption logc_ST using "tables\Online Appendix Table C`name'", ///
               excel se bdec(3) addstat("mean of dep var",`m1') append  cttop("OLS")

	
`cmd1' mistarget_hypothetical selftargeting,  cl(kecagroup)
qui summ mistarget_hypothetical if e(sample)
local m1=r(mean)	
outreg2 selftargeting using "tables\Online Appendix Table C`name'", ///
               excel se bdec(3) addstat("mean of dep var",`m1') append eq(auto) cttop("ols")


`cmd1' excl_error_hypothetical selftargeting, cl(kecagroup)
qui summ excl_error_hypothetical if e(sample)
local m1=r(mean)
outreg2 selftargeting using "tables\Online Appendix Table C`name'", ///
               excel se bdec(3) addstat("mean of dep var",`m1') append eq(auto) cttop("ols")


`cmd1' incl_error_hypothetical selftargeting,  cl(kecagroup)
qui summ incl_error_hypothetical if e(sample)
local m1=r(mean)
outreg2 selftargeting using "tables\Online Appendix Table C`name'", ///
               excel se bdec(3) addstat("mean of dep var",`m1') append eq(auto) cttop("ols")
			   
}
* eof version 1 No Stratum FE



***Stratum FE - clogit and OLS
{
areg logconsumption selftargeting if getbenefit_hypothetical==1, a(kecagroup) cl(hhea) 
qui summ logconsumption if e(sample)
local m = r(mean)
outreg2 selftargeting using "tables\Online Appendix Table C`name'", ///
nocons nor  excel se bdec(3) addstat("mean of dep var",`m') append eq(auto)


`cmd2' getbenefit_hypothetical selftargeting logconsumption logc_ST, `suf2'(kecagroup)  cl(kecagroup)
qui summ getbenefit_hypothetical if e(sample)
local m1 = r(mean)
outreg2 selftargeting logconsumption logc_ST using "tables\Online Appendix Table C`name'", ///
               excel se bdec(3) addstat("mean of dep var",`m1') /// 
			   append  cttop("ols")
		   
		   
`cmd2' mistarget_hypothetical selftargeting, `suf2'(kecagroup)  cl(kecagroup)
qui summ mistarget_hypothetical if e(sample)
local m1=r(mean)	
outreg2 selftargeting using "tables\Online Appendix Table C`name'", ///
               excel se bdec(3) addstat("mean of dep var",`m1') append cttop("ols")


`cmd2' excl_error_hypothetical selftargeting, `suf2'(kecagroup)  cl(kecagroup)
qui summ excl_error_hypothetical if e(sample)
local m1=r(mean)
outreg2 selftargeting using "tables\Online Appendix Table C`name'", ///
               excel se bdec(3) addstat("mean of dep var",`m1') append cttop("ols")


`cmd2' incl_error_hypothetical selftargeting, `suf2'(kecagroup)  cl(kecagroup)
qui summ incl_error_hypothetical if e(sample)
local m1=r(mean)
outreg2 selftargeting using "tables\Online Appendix Table C`name'", ///
               excel se bdec(3) addstat("mean of dep var",`m1') append cttop("ols")

}
}
