***Table 5. Experimental Comparison of Targeting under Self-Targeting and Automatic Screening Treatments

clear all
pause on
set more off

set sortseed 10000

local STfolder = "$STfolder"
cd "`STfolder'"

***

**** Get Data/Prep Variables
use "data\codeddata\baseline\matched_baseline.dta",clear

*generate interaction terms
gen cons_ST=logconsumption*selftargeting

*append midline data
append using "data\codeddata\midline\matched_midline.dta", gen(base_or_end) keep(getbenefit flag_newHH logconsumption selftargeting hhea kecagroup)
keep if base_or_end==0 | flag_newHH==1

**** Regressions

***No Stratum FE
reg logconsumption selftargeting if getbenefit==1 & base_or_end==0, cl(hhea)
qui summ logconsumption if e(sample)
local m0 = r(mean)
outreg2 using "tables\Table 5", excel se bdec(3) addstat("mean of dep var",`m0') replace

reg logconsumption selftargeting base_or_end if getbenefit==1, cl(hhea)
qui summ logconsumption if e(sample)
local m0 = r(mean)
outreg2 using "tables\Table 5", excel se bdec(3) addstat("mean of dep var",`m0') append

logit getbenefit selftargeting logconsumption cons_ST if base_or_end==0, cl(hhea)
qui summ getbenefit if e(sample)
local m0 = r(mean)
outreg2 using "tables\Table 5", excel se bdec(3) addstat("mean of dep var",`m0')append

logit mistarget selftargeting if base_or_end==0, cl(hhea)
qui summ mistarget if e(sample)
local m6=r(mean)	
outreg2 using "tables\Table 5", excel se bdec(3) addstat("mean of dep var",`m6') append

logit excl_error selftargeting if base_or_end==0, cl(hhea)
qui summ excl_error if e(sample)
local m4=r(mean)
outreg2 using "tables\Table 5", excel se bdec(3) addstat("mean of dep var",`m4') append

logit incl_error selftargeting if base_or_end==0, cl(hhea)
qui summ incl_error if e(sample)
local m5=r(mean)
outreg2 using "tables\Table 5", excel se bdec(3) addstat("mean of dep var",`m5') append



***With Stratum FE
areg logconsumption selftargeting if getbenefit==1 & base_or_end==0, ab(kecagroup) cl(hhea)
qui summ logconsumption if e(sample)
local m0 = r(mean)
outreg2 using "tables\Table 5 panelB", excel se bdec(3) addstat("mean of dep var",`m0') replace

areg logconsumption selftargeting base_or_end if getbenefit==1, ab(kecagroup) cl(hhea)
qui summ logconsumption if e(sample)
local m0 = r(mean)
outreg2 using "tables\Table 5 panelB", excel se bdec(3) addstat("mean of dep var",`m0') append

clogit getbenefit selftargeting logconsumption cons_ST if base_or_end==0, group(kecagroup)  cl(kecagroup)
qui summ getbenefit if e(sample)
local m0 = r(mean)
outreg2 using "tables\Table 5 panelB", excel se bdec(3) addstat("mean of dep var",`m0')append

clogit mistarget selftargeting if base_or_end==0, group(kecagroup)  cl(kecagroup)
qui summ mistarget if e(sample)
local m6=r(mean)	
outreg2 using "tables\Table 5 panelB", excel se bdec(3) addstat("mean of dep var",`m6') append

clogit excl_error selftargeting if base_or_end==0, group(kecagroup) cl(kecagroup)
qui summ excl_error if e(sample)
local m4=r(mean)
outreg2 using "tables\Table 5 panelB", excel se bdec(3) addstat("mean of dep var",`m4') append

clogit incl_error selftargeting if base_or_end==0, group(kecagroup) cl(kecagroup)
qui summ incl_error if e(sample)
local m5=r(mean)
outreg2 using "tables\Table 5 panelB", excel se bdec(3) addstat("mean of dep var",`m5') append

