*** Table 6: Comparison of Targeting under Self-Selection and Hypothetical Universal Automatic Targeting using Baseline Data

/*
Notation:

ST = self targeting
AE = automatic enrollment 
HUAE = hypothetical universal EA

1 - use govt data
2 - use mixed data (govt data on those who show up, baseline data on the rest)
3 - use baseline data on everyone
*/

clear all
pause on
set more off

* used to make outreg2 output look a bit nicer
prog drop _all
prog define eqmatch
 syntax anything
 gettoken one two: anything
 local one=trim("`one'")
 local two=trim("`two'")
 split varname, parse(":") gen(_varname)
 replace eqname="`one'" if eqname=="`two'"
 replace report=/*eqname+":"+*/_varname2
end

set seed 345789
set sortseed 10000

local STfolder = "$STfolder"
cd "`STfolder'"

***

**** Get Data/Prep Variables

use "data\codeddata\baseline\matched_baseline.dta", clear

*ST3 versus HUAE3 in AE sample using suseti poverty line and noisy PMT
	gen     getbenefit_hypothetical = (pcexppred_noise < povertyline3_noise)
	replace getbenefit_hypothetical = 0 if showup==0 & selftargeting==1


*generate errors for hypothetical beneficiaries
	gen     excl_error_hypothetical=0 if verypoor_povertyline1==1 & getbenefit_hypothetical==1
	replace excl_error_hypothetical=1 if verypoor_povertyline1==1 & getbenefit_hypothetical==0

	gen     incl_error_hypothetical=0 if  verypoor_povertyline1==0 & getbenefit_hypothetical==0
	replace incl_error_hypothetical=1 if  verypoor_povertyline1==0 & getbenefit_hypothetical==1

	gen     mistarget_hypothetical = excl_error_hypothetical
	replace mistarget_hypothetical = incl_error_hypothetical if mistarget_hypothetical==.

	tab excl_error_hypothetical, missing
	tab incl_error_hypothetical, missing
	tab  mistarget_hypothetical, missing

*generate interaction terms
	gen logc_ST = logconsumption * selftargeting

**** Regressions: Compare ST to (hypothetical AE on the entire sample)

*** No Stratum FEs
{
reg logconsumption selftargeting if getbenefit_hypothetical==1, cl(hhea)
qui summ logconsumption if e(sample)
local m = r(mean)
outreg2 selftargeting using "tables\Table 6", ///
nocons nor excel eq(auto) se bdec(3) addstat("mean of dep var",`m') replace 


logit getbenefit_hypothetical selftargeting logconsumption logc_ST,  cl(kecagroup)
qui summ getbenefit_hypothetical if e(sample)
local m1 = r(mean)
outreg2 selftargeting logconsumption logc_ST using "tables\Table 6", ///
               excel se bdec(3) addstat("mean of dep var",`m1') eq(auto) append  cttop("logit")

	
logit mistarget_hypothetical selftargeting,  cl(kecagroup)
qui summ mistarget_hypothetical if e(sample)
local m1=r(mean)	
outreg2 selftargeting using "tables\Table 6", ///
               excel se bdec(3) addstat("mean of dep var",`m1') append eq(auto) cttop("logit")


logit excl_error_hypothetical selftargeting, cl(kecagroup)
qui summ excl_error_hypothetical if e(sample)
local m1=r(mean)
outreg2 selftargeting using "tables\Table 6", ///
               excel se bdec(3) addstat("mean of dep var",`m1') append eq(auto) cttop("logit")


logit incl_error_hypothetical selftargeting,  cl(kecagroup)
qui summ incl_error_hypothetical if e(sample)
local m1=r(mean)
outreg2 selftargeting using "tables\Table 6", ///
               excel se bdec(3) addstat("mean of dep var",`m1') append eq(auto) cttop("logit")
			   
}


***Stratum FE - clogit and OLS
{
areg logconsumption selftargeting if getbenefit_hypothetical==1, a(kecagroup) cl(hhea) 
qui summ logconsumption if e(sample)
local m = r(mean)
outreg2 selftargeting using "tables\Table 6", ///
nocons nor  excel se bdec(3) addstat("mean of dep var",`m') append eq(auto)




clogit getbenefit_hypothetical selftargeting logconsumption logc_ST, group(kecagroup) cl(kecagroup)
qui summ getbenefit_hypothetical if e(sample)
local m1 = r(mean)
outreg2 selftargeting logconsumption logc_ST using "tables\Table 6", ///
               excel se bdec(3) addstat("mean of dep var",`m1') /// 
			   append  cttop("logit")
		   
		   
clogit mistarget_hypothetical selftargeting, group(kecagroup)  cl(kecagroup)
qui summ mistarget_hypothetical if e(sample)
local m1=r(mean)	
outreg2 selftargeting using "tables\Table 6", ///
               excel se bdec(3) addstat("mean of dep var",`m1') append cttop("logit")


clogit excl_error_hypothetical selftargeting, group(kecagroup)  cl(kecagroup)
qui summ excl_error_hypothetical if e(sample)
local m1=r(mean)
outreg2 selftargeting using "tables\Table 6", ///
               excel se bdec(3) addstat("mean of dep var",`m1') append cttop("logit")


clogit incl_error_hypothetical selftargeting, group(kecagroup)  cl(kecagroup)
qui summ incl_error_hypothetical if e(sample)
local m1=r(mean)
outreg2 selftargeting using "tables\Table 6", ///
               excel se bdec(3) addstat("mean of dep var",`m1') append cttop("logit")

}




