/* CODING baseline survey data : SUSETI */

clear all
pause on
set more off

local STfolder = "$STfolder"
cd "`STfolder'data\"


*****
/* CREATE LOG PER CAPITA CONSUMPTION AND RANK CONSUMPTION*/
****

	use "originaldata\baseline\hh_ks1.dta",clear

	merge 1:1 hhid using "originaldata\baseline\hh_ks2.dta"
	assert _merge==3
	drop _merge
	sum

	/* recode missing values, don't know and not applicable to missing */
	foreach var of varlist ks01_1a - ks01_14b{
		gen missing_`var' = (`var'>=999990)
		replace `var'=. if `var'>=999990
	}

	foreach var of varlist  ks03_15a - ks04_20{
		gen missing_`var' = (`var'>=99999990)
		replace `var'=. if `var'>=99999990
	}

	egen missing = rsum( missing_ks01_1a- missing_ks04_20 )

	egen wfood = rsum(ks01_1a - ks01_14b)
	label var wfood "The value of food consumed last week"
	gen mfood = wfood * 30/7
	label var mfood "Monthly food consumtion"

	/*typo in variable names. Correct*/
	rename ks03_17 ks04_17
	rename ks03_18 ks04_18

	egen x = rsum(ks03_15a ks03_15c ks03_15d ks03_16a ks03_16d ks03_16e)
	egen y = rsum(ks04_15b ks04_16b ks04_16c ks04_17 ks04_18 ks04_19a ks04_19b ks04_19c ks04_19d ks04_20)
	gen mnonfood = x + (y/12)
	label var mnonfood "Monthly non food consumption"

	gen hhconsumption = (mfood + mnonfood)
	replace hhconsumption=. if missing>=4 
	label var hhconsumption "Monthly household consumption in Rp"
	drop missing*

	gen hhea = substr(hhid,1,3)

	tempfile b
	save `b',replace 


	/* Merge with household size data to get per capita consumption*/

	use "originaldata\baseline\hh_ar1.dta",clear

	merge 1:1 hhid using `b'
	assert _merge==3
	drop _merge

	label var hhsize "Household size"
	gen hhsize2 = hhsize^2
	label var hhsize2 "Household Size Squared"
	gen hhsize_1 = (hhsize==1)
	label var hhsize_1 "Household is single household"

	gen loghhsize = log(hhsize)
	label var loghhsize "Log household size"

	gen consumption = (hhconsumption/hhsize)
	label var consumption "Per capita consumption (in Rp)"

	gen logconsumption = log(consumption)
	label var logconsumption "Log per capita consumption"

	bys hhea: egen rank_pcexp = rank(consumption)
	label var rank_pcexp "Rank per capita consumption within village"
	bys hhea: gen nhhrank_pcexp=_N
	label var nhhrank_pcexp "number of household in village"

	gen rankconsumption= rank_pcexp/nhhrank_pcexp
	label var rankconsumption "Rank per capita consumption within village in percentiles"

	compress
	drop ar* ks* x y
	sort hhid
	label variable hhea "Household enumeration area (village)"

	cap mkdir  "codeddata"
	cap mkdir  "codeddata\baseline"
	saveold    "codeddata\baseline\consumption.dta", replace


******
/* Characteristics of HH head*/
******

	use "originaldata\baseline\hh_ar2.dta", clear

	keep if ar02==1 /* keep household head */

	rename ar03 hhmale
	recode hhmale (3=0)
	label var hhmale "Head of Household is Male"

	rename ar04a_yr hhage /*age in years, ignoring months*/
	recode hhage (0 5 998 90 95=.)
	label var hhage "Age of head of household"

	gen hhmarried=ar06
	recode hhmarried (1 3 4 5=0) (2=1)
	label var hhmarried "Head of household is married"
	gen hhwidow=ar06
	recode hhwidow(1 2 3 5=0) (4=1)
	label var hhwidow "Head of household is widow"

	gen hhage2 = hhage^2
	label var hhage2 "Age of head of household squared"

	gen hhmalemarr = hhmale * hhmarried
	label var hhmalemarr "Head of household is male and married"
	
	gen hhsd=(ar17==2|ar17==5)
	label var hhsd "Education Attaintment of HH Head is elementary School"
	gen hhsmp = (ar17==3|ar17==6)
	label var hhsmp "Education Attaintment of HH Head is Junior School"
	gen hhsma=(inlist(ar17,4,7,8,9,10))
	label var hhsma "Education Attaintment of HH Head is Senior+"

	/*main activity of the household head*/
	gen hhsector1 = (inrange(ar08,1,5))
	label var hhsector1 "Head of household works in agriculture sector"
	gen hhsector2 = (inrange(ar08,6,9))
	label var hhsector2 "Head of household works in industry sector"
	gen hhsector3 = (inrange(ar08,10,13))
	label var hhsector3 "Head of household works in service sector"

	gen formal = (inrange(ar07,3,5))
	label var formal "Head of household works in formal sector"
	gen informal = (inrange(ar07,1,2)|inrange(ar07,6,8))
	label var informal "Head of household works in informal sector"


	recode ar17 (95 98 99=.)
	recode ar18 (98=.)
	recode ar18 (96=0) /*not yet in school*/
	gen yreducationhhhead=0 if ar17==0 
	label var yreducationhhhead "Years of education of HH Head "
	*if graduated: ar18==7
	replace yreducationhhhead=1 if ar18==7 & ar17==1
	replace yreducationhhhead=6 if ar18==7 & (ar17==2 | ar17==5)
	replace yreducationhhhead=9 if ar18==7 & (ar17==3 | ar17==6)
	replace yreducationhhhead=12 if ar18==7& (ar17==4 | ar17==7)
	replace yreducationhhhead=14 if ar18==7 & ar17==8
	replace yreducationhhhead=16 if ar18==7 & ar17==9
	replace yreducationhhhead=18 if ar18==7 & ar17==10

	*if didn't graduate: ar18!=7--take the previous step and add ar18
	replace yreducationhhhead=0+ar18 if ar18!=7 & ar17==1
	replace yreducationhhhead=1+ar18 if ar18!=7 & (ar17==2 | ar17==5)
	replace yreducationhhhead=6+ar18 if ar18!=7 & (ar17==3 | ar17==6)
	replace yreducationhhhead=9+ar18 if ar18!=7& (ar17==4 | ar17==7)
	replace yreducationhhhead=12+ar18 if ar18!=7 & ar17==8
	replace yreducationhhhead=14+ar18 if ar18!=7 & ar17==9
	replace yreducationhhhead=16+ar18 if ar18!=7 & ar17==10

	rename ar17 educationhhhead
	label var educationhhhead "Education level of hh head"
	*label define education 0 "0. Never attended school" 1 "1. Kindergarden" 2 "2. Primary" 3 "3. Junior High" 4 "4. Senior High" 5 "5. Packet A" 6 "6. Packet B" 7 "7. Packet C" 8 "8. D1/D2/D3" 9 "9. D4/BBachelor's" 10 "10. Master's/PHD" 98 "98. Don't know" 95 "95. Others"

	drop ar*

	compress
	sort hhid

	saveold "codeddata\baseline\hhhead.dta", replace

*****
/* pct of hh that are agricultural and log number of hh per RT*/
*****

/* let a hh be agricultural hh if the head is in agricultural sector */

	use "codeddata\baseline\hhhead.dta",clear

	gen hhea=substr(hhid,1,3)

	collapse (sum) hhsector1, by (hhea)
	rename hhsector1 totagriculturehhinRT

	merge 1:1 hhea using "originaldata\baseline\k_data.dta"
	assert _merge==3
	drop   _merge 

	gen pctagriculturalhh=totagriculturehhinRT/tothhinRT
	la var totagriculturehhinRT "total number of agriculture households in RT"
	la var pctagriculturalhh "percentage of agriculture households in RT"
	la var tothhinRT "total number of households in RT"

	keep  hhea tothhinRT totagriculturehhinRT pctagriculturalhh

	saveold "codeddata\baseline\pctagriculture.dta",replace

*****
/* EDUCATION LEVEL OF RT HEAD */
*****

	use "originaldata\baseline\k_data.dta",clear
	keep hhid  
	sort hhid

	tempfile d
	save `d',replace 

	use "codeddata\baseline\hhhead.dta",clear 

	merge 1:1 hhid using `d'  //NOTE: RT head for hhea==472 (hhid==472003) is not surveyed in the baseline.

	tab _merge
	keep if _merge==3|hhid=="472003"
	drop _merge

	rename educationhhhead educationrthead
	rename yreducationhhhead yreducationrthead

	label var educationrthead "Education level of RT head"
	label val educationrthead education

	label var yreducationrthead "Years of education of RT Head "

	gen hhea = substr(hhid,1,3)
	label variable hhea "Household enumeration area (village)"

	keep hhid hhea educationrthead yreducationrthead

	saveold "codeddata\baseline\rthead.dta", replace



*****
/* Distance to kecamatan*/
*****

	use "originaldata\baseline\hh_ts.dta",clear
	gen hhea = substr(hhid,1,3)
	keep if tstype=="b"   /*information on kecamatan*/

	rename ts01 distance
	recode distance (999.8 998=.)

	merge 1:1 hhid using "codeddata\baseline\rthead.dta"

	tab _merge
	keep if _merge==1    /*exclude RT head's distance when calculating the average*/
	drop _merge

	collapse (mean) distance, by (hhea)
	la var distance "Distance to kecamatan"

	saveold "codeddata\baseline\distance_kec.dta",replace


*****
/* CREATE ALL HOUSEHOLD CHARACTERISTICS FOR PMT */
*****

	use "originaldata\baseline\hh_kr1", clear

	gen asset_tbggas= (kr09==5)

	rename kr05 floorsize 	
	recode floorsize (995 998 999=.)

	gen tfloor = (kr04a !=6)
	replace tfloor=. if kr04a==95
	gen twall = (kr03a ==1) 
	replace twall=. if kr03a==95
	gen troof = (inrange(kr02a,1,2))
	replace troof=. if kr02a==95
	gen toilet = (kr07 ==2)
	replace toilet=. if kr07==95
	gen dwater = (inlist(kr06,1,2,3,4,6))
	replace dwater = . if kr06==95

	gen lighting = (kr08==3)
	gen house = (kr01 ==1)
	gen fcook = (kr09 ==1)
	gen floorquality = (kr04!=1)
	gen micro = (kr13==1)

	label var floorsize "Floor area"
	label var tfloor "Not earth floor"
	label var troof "Concrete or corrugated roof"
	label var twall "Brick or cement wall"
	label var toilet "Private toilet"
	label var dwater "Clean drinking water"
	label var lighting "PLN electricity"
	label var house "Own house privately"
	label var fcook "Cooks with firewood"
	label var floorquality "High floor material top quality"


	keep hhid micro asset_tbggas floorsize tfloor troof twall toilet dwater lighting house fcook floorquality

	compress
	sort hhid

	gen hhea=substr(hhid,1,3)
	saveold "codeddata\baseline\hhcharacteristic.dta", replace


*****
/* OTHER HH CHARACTERISTIC FOR PMT */
*****

	use "originaldata\baseline\hh_ar2", clear

	recode ar04a_yr (998=.)
	gen age04 = (inrange(ar04a_yr,0,4))
	gen age14 = (inrange(ar04a_yr,0,14))
	gen age65 = (ar04a_yr >64)
	gen age1564 = (inrange(ar04a_yr,15,64))

	//age groups
	gen count_below5=0
	replace count_below5=1 if ar04a_yr<6
	gen count_below10=0
	replace count_below10=1 if 5<ar04a_yr&ar04a_yr<11
	gen count_below15=0
	replace count_below15=1 if 10<ar04a_yr&ar04a_yr<16
	gen count_0to3=0
	replace count_0to3=1 if ar04a_yr<4
	gen count_4to5=0
	replace count_4to5=1 if ar04a_yr>=4&ar04a_yr<=5
	gen count_6to12=0
	replace count_6to12=1 if ar04a_yr>=6&ar04a_yr<=12
	gen count_13to15=0
	replace count_13to15=1 if ar04a_yr>=13&ar04a_yr<=15

	gen eschild = (inlist(ar17,2,5) & ar04a_yr>=4 & ar04a_yr<=19)
	gen smpchild = (inlist(ar17,3,6) & ar04a_yr>=4 & ar04a_yr<=18)
	gen sschild = (inlist(ar17,4,7,8,9,10) & ar04a_yr>=4 & ar04a_yr<=18)

	bys hhid: egen maxar17=max(ar17)
	gen hhmaxedsd=(inlist(maxar17,2,5))
	gen hhmaxedsmp=(inlist(maxar17,3,6))
	gen hhmaxedsma=(inlist(maxar17,4,7,8,9,10))

	collapse (sum) count_below5 count_below10 count_below15 count_0to3 count_4to5 count_6to12 count_13to15 age04 age14 age65 age1564 eschild smpchild sschild (mean) hhmaxedsd hhmaxedsmp hhmaxedsma, by(hhid)

	gen depratio = (age14 + age65) / age1564
	gen depratio_c = age14 / age1564
	gen depratio_a = age65 / age1564

	rename count_below5 childrenbelow5
	rename count_below10 children6to10
	rename count_below15 children11to15
	rename count_0to3 children0to3
	rename count_4to5 children4to5
	rename count_6to12 children6to12
	rename count_13to15 children13to15

	label var age04	"Number of children 0-4"
	label var age14 "Number of children 0-14"
	label var age65	"Number of adults over 64"
	label var age1564 "Number of adults 15-64"

	label var hhmaxedsd "Highest Education Attaintment within HH is Elementary School"
	label var hhmaxedsmp "Highest Education Attaintment within HH is Junior School"
	label var hhmaxedsma "Highest Education Attaintment within HH is Senior +"

	label var eschild "Number of Children in Elementary School"
	label var smpchild "Number of Children in Junior H.Schoo"
	label var sschild "Number of Children in Senior H.School"
	label var depratio "Total Dependency Ratio"
	label var depratio_c "Child Dependency Ratio"
	label var depratio_a "Aged Dependency Ratio"

	compress
	sort hhid
	saveold "codeddata\baseline\hh_ar2", replace


*****
/* CREATE ALL ASSET VARIABLES FOR PMT */
*****

	use "originaldata\baseline\hh_hr2", clear
	keep hhid hr2type hr03x hr03
	recode hr03x (3 8=0) (7 9=.) /* Recode 3.No and 8. Don't know to 0; recode 7. don't want to answer and 9. missing to . */
	recode hr03 (997 =.) /* Recode 997. don't want to answer to . (missing) */

	reshape wide hr03x hr03, i(hhid) j(hr2type) string
	
	gen asset_mobilboat=(hr03x24==1|hr03x25==1)
	replace asset_mobilboat=. if hr03x24==. & hr03x25==.
	gen asset_motor=hr03x23
	gen asset_kulkas=hr03x09
	gen asset_sepeda=hr03x13

	drop hr*
	compress
	sort hhid

	saveold "codeddata\baseline\hhasset.dta", replace



