/*match government PMT and selftargeting survey data with study survey data */

clear all
pause on
set more off

set sortseed 10000

local STfolder = "$STfolder"
cd "`STfolder'data\"

*********
*For Self-targeting
*********

	use "codeddata\baseline\coding_suseti_pmt.dta", clear
	keep  hhid hhea prov logconsumption consumption pcexppred PMTSCORE
	order hhid hhea prov logconsumption consumption pcexppred PMTSCORE

	merge 1:1 hhid using "originaldata\precoded\govt_crosswalk_baseline.dta"
	assert  _m==3
	keep if _m==3
	drop _m
	
	keep if maintreatment==2
	
	merge m:1 hhea using "originaldata\other\randomization.dta"
	keep if _merge==3
	drop    _merge

	tempfile match_ST_SUSETI
	save    `match_ST_SUSETI'


*******
*For PMT
*******/
	
	use "codeddata\baseline\coding_suseti_pmt",clear
	//keep  hhid hhea prov /*kab kec desa  r401c*/ logconsumption consumption pcexppred PMTSCORE
	order hhid hhea prov kecagroup logconsumption consumption pcexppred PMTSCORE
	
	merge 1:1 hhid using "originaldata\precoded\govt_crosswalk_baseline.dta"
	assert  _m==3
	keep if _m==3
	drop _m
	
	merge m:1 hhea using "originaldata\other\randomization.dta"
	keep if _merge==3
	drop    _merge
	
	merge m:1 hhea using "originaldata\baseline\k_data.dta"
	assert _m==3
	drop _m
	
	keep if maintreatment==1
		
	bys maintreatment: egen totHH=sum (tothhinRT)
	//sum totHH if maintreatment==1		/*total number of households in the PMT RTs*/

	append using `match_ST_SUSETI'

	tempfile matched_baseline
	save	`matched_baseline'
	
**************************
** Define poverty lines **
**************************
* povertyline1 is the 16th percentile of the consumption distribution, by province-urban cell
* 	 very poor is 80% of this poverty line
* povertyline2 is the government's PMT cutoff
* povertyline3 is the constructed similar to the govt's PMT cutoff, using 
*    baseline data. Specifically, we first find the consumption percentile 
*    corresponding to the very poor in each (province-urban) cell, and
*    then the cutoff is the PMT score at that percentile, in the cell.
* povertyline3_noise is the same as pov3 except the PMT is noisied up
*    add noise to the PMTSCORE to make the baseline data more similar to govt data
*    value sigma = 0.45 chosen based on simulations, to match exclusion error from govt data

	use "codeddata\baseline\coding_suseti_pmt",clear

** Poverty line 1
	bysort prov urban: egen povertyline1=pctile(consumption), p(16)		
	gen      verypoor_povertyline1 =0
	replace  verypoor_povertyline1 =1 if consumption<0.8*povertyline1	
	
	* define very poor line (percentile) in each of the 6 cells
	bysort  prov urban: egen n_below_line =   sum(verypoor_povertyline1)
	bysort  prov urban: egen n_group      = count(verypoor_povertyline1)
	gen     povertyline3_pctile = n_below_line / n_group * 100
	
	drop n_below_line n_group

	
** Poverty line 2
	gen     povertyline2=240315.5 if prov==1 & urban==1
	replace povertyline2=206641.8 if prov==1 & urban==0
	replace povertyline2=200971.1 if prov==2 & urban==1
	replace povertyline2=188815.4 if prov==2 & urban==0
	replace povertyline2=185687.0 if prov==3 & urban==1
	replace povertyline2=172602.8 if prov==3 & urban==0
	gen     verypoor_povertyline2 = 0
	replace verypoor_povertyline2 = 1 if consumption<=0.8*povertyline2

** Poverty line 3

	merge 1:1 hhid using `matched_baseline'
	assert _m!=2
	keep if _m==3
	drop _m
	
	gen povertyline3=.
	
	forv prov=1/3{
	forv urba=0/1{
		
	sum povertyline3_pctile if prov==`prov' & urban==`urba'
	local pctile = r(mean)

	cap drop temp
	egen temp = pctile(pcexppred)  if prov==`prov' & urban==`urba', p(`pctile')		
	replace povertyline3 = temp    if prov==`prov' & urban==`urba'
	}
	}
	
** Poverty line 3 with noise	
		
	sort hhid 	
	set seed 345789

	* generate noise and add to PMT score
	* using noise standard deviation = 0.45
	* see paper for details
	gen noise = rnormal(0,0.45)
	
	gen PMTSCORE_noise = PMTSCORE + noise
	gen pcexppred_noise = exp(PMTSCORE_noise)
		
**  poverty line with noise
	gen povertyline3_noise=.

	*** one line per region
		forv prov=1/3{
		forv urba=0/1{
		
		sum povertyline3_pctile if prov==`prov' & urban==`urba'
		local pctile = r(mean)

		cap drop temp
		egen temp = pctile(pcexppred_noise)  if prov==`prov' & urban==`urba', p(`pctile')		
		replace povertyline3_noise = temp    if prov==`prov' & urban==`urba'
		}	
		}	
	
	drop temp noise
	
** smooth poverty line with noise	
	* expand the data 1000 times and add noise to the PMTSCORE
	* then find the line corresponding to 80% of the 16th percentile
	preserve
		cap drop pcexppred_noise PMTSCORE_noise 
		
		expand 1000, gen(dupl)
		
		gen noise = rnormal(0,0.45)
		
		gen PMTSCORE_noise = PMTSCORE + noise
		gen pcexppred_noise = exp(PMTSCORE_noise)
			
		gen povertyline3_noise_smooth=.

		*** one line per region
			forv prov=1/3{
			forv urba=0/1{
			
			sum povertyline3_pctile if prov==`prov' & urban==`urba'
			local pctile = r(mean)

			cap drop temp
			egen temp = pctile(pcexppred_noise)  if prov==`prov' & urban==`urba', p(`pctile')		
			replace povertyline3_noise_smooth = temp       if prov==`prov' & urban==`urba'
			}	
			}	
			
		keep prov urban povertyline3_noise_smooth
		duplicates drop
		tempfile povertyline
		save	`povertyline'
	restore

		merge m:1 prov urban using `povertyline'
		assert _m==3
		drop _m
		

* merge in baseline control variables
* hh head education, # of household members, share in HH age 0-3,4-5,6-12,13-15, hh head gender, hh head widow.
	merge 1:1 hhid using "codeddata\baseline\hhhead", keepusing(hhid educationhhhead hhmale hhwidow)
	*assert _merge!=1
	keep if _merge==3
	drop _merge
	merge 1:1 hhid using "codeddata\baseline\consumption", keepusing(hhid hhsize)
	assert _merge!=1
	keep if _merge==3
	drop _merge
	merge 1:1 hhid using "codeddata\baseline\hh_ar2", keepusing(hhid children0to3 children4to5 children6to12 children13to15)
	assert _merge!=1
	keep if _merge==3
	drop _merge
	

* generate errors using very poor from the 1st poverty line (80% of the 16th 
* percentile of the consumption distribution in the SUSETI data)

	gen     excl_error=0 if verypoor_povertyline1==1 & getbenefit==1
	replace excl_error=1 if verypoor_povertyline1==1 & getbenefit==0 

	gen     incl_error=0 if verypoor_povertyline1==0 & getbenefit==0
	replace incl_error=1 if verypoor_povertyline1==0 & getbenefit==1

	gen     mistarget = excl_error
	replace mistarget = incl_error if mistarget==.

	saveold "codeddata\baseline\matched_baseline.dta",replace
