 * CODING interim midline data : SUSETI 
  
clear all
pause on
set more off

set sortseed 10000

local STfolder = "$STfolder"
cd "`STfolder'data\"


**************************************
**Basic Household Info (COV section)**
**************************************

	use "originaldata\midline\hh_cov.dta",clear

	*Keep household size information to calculate per capita consumption*
	rename cov2_no hhsize
	la var hhsize "Household size"
	keep hhid hhsize
	tempfile hhsize
	save `hhsize.dta', replace


*****************************
**Consumption (RP1 section)**
*****************************

	use "originaldata\midline\hh_rp1.dta",clear

	*Monthly net income*
	*gen hh_net_income=subinstr(rp01, "_","0",.)
	*replace hh_net_income=subinstr(hh_net_income, ".","",1)
	*destring hh_net_income, replace
	rename rp01 hh_net_income
	la var hh_net_income "Monthly net income"

	***Food Consumption***

	*Generate consumption on food to be sum of above*
	egen wfood=rsum(rp02_1_a-rp02_14_b)
	la var wfood "Consumption on food last week"

	*Convert to montly consumption*
	gen mfood = wfood * 30/7
	la var mfood "Monthly food consumtion"

	***Nonfood Consumption***

	*Correct typo in variable names*
	rename rp04_17 rp05_17
	rename rp04_18 rp05_18

	*Convert to monthly consumption*
	egen m=rsum(rp04_15_a rp04_15_c rp04_15_d rp04_16_a rp04_16_d rp04_16_e)
	egen y=rsum(rp05_15_b rp05_16_b rp05_16_c rp05_17 rp05_18 rp05_19_a rp05_19_b rp05_19_c rp05_19_d rp05_20)
	gen mnonfood=m+(y/12)
	la var mnonfood "Monthly nonfood consumption"
	drop m y

	*Total household monthly consumption*
	gen hhconsumption = (mfood + mnonfood)
	la var hhconsumption "Monthly household consumption in Rp"

	merge 1:1 hhid using `hhsize.dta'
	*This is not a perfect 1:1 merge since there are 1092 obs in COV but only 1035 obs in RP1.*
	assert _merge!=1
	drop if _merge!=3
	*We only need to keep households with consumption information*
	drop _merge

	gen hhsize2 = hhsize^2
	gen hhsize_1 = (hhsize==1)
	gen loghhsize = log(hhsize)
	gen consumption = (hhconsumption/hhsize)
	gen logconsumption = log(consumption)
	la var hhsize2 "Household Size Squared"
	la var hhsize_1 "Household is single household"
	la var loghhsize "Log household size"
	la var consumption "Per capita consumption (in Rp)"
	la var logconsumption "Log per capita consumption"

	gen hhea=substr(hhid,1,3)
	bys hhea: egen rank_pcexp = rank(consumption)
	la var rank_pcexp "Rank per capita consumption within village"
	bys hhea: gen nhhrank_pcexp=_N
	la var nhhrank_pcexp "number of household in village"

	gen    rankconsumption= rank_pcexp/nhhrank_pcexp
	la var rankconsumption "Rank per capita consumption within village in percentiles"

	drop rp02_1_a- rp05_20
	
	compress
	cap mkdir "codeddata\midline"
	saveold   "codeddata\midline\consumption.dta",replace
	

*********************
** Matched Midline **
*********************
	
***For new HH in midline survey only: 745 HH in total***
	use "originaldata\precoded\govt_crosswalk_midline.dta",clear

	merge 1:1 hhid using "codeddata\midline\consumption.dta", keepusing(hhea logconsumption consumption)
	assert _m==3
	drop _m
	
//	merge 1:1 hhid using "originaldata_raw\midline_location_coded.dta", keepusing()
//	keep hhid logconsumption consumption hhea prov kab kec desa urban flag_newHH 
	
	merge m:1 hhea using "originaldata\other\randomization.dta"
	assert _m!=1
	keep if _m==3
	drop _m

***Define the poverty line as the 16th percentile in the SUSETI in per capita expenditure in the midline, by district. Let's define "very poor" as less than 0.8 * the poverty line. ***
	bysort prov urban: egen povertyline1=pctile(consumption), p(16)
	gen     verypoor_povertyline1=0
	replace verypoor_povertyline1=1 if consumption<=0.8*povertyline1
	
	saveold "codeddata\midline\matched_midline.dta",replace
	
