* Prepare data for model calibration
* Original code mostly written by He Yang
* Modified by Ariel Zucker
* Modified by Donghee Jo

clear all
pause on
set more off

set sortseed 10000

local STfolder = "$STfolder"
cd "`STfolder'data\"
di "`STfolder'"

********************
*** Preparations ***
********************
	
* total cost from interim midline survey
	use "originaldata\midline\hh_ap1.dta",clear

	//rename ap01 treatment
	rename ap02 ever_try
	//rename ap04 member_sign_up
	//gen time_arrived=ap05_hr+(ap05_mnt/60) if ap05_hr!=. & ap05_mnt!=.

	//la var treatment "Treatment assigned to this village"
	la var ever_try "Whether a member of household every tried to sign up for PKH"
	//la var member_sign_up "Which household member went to sign up for PKH"
	//la var time_arrived "Time arrived in the interview site"

	egen total_waiting_hour_all_1 =rsum(ap08_a_hr ap08_b_hr ap08_c_hr ap08_d_hr ap08_e_hr ap08_f_hr ap08_g_hr ap08_v_hr)
	egen total_waiting_min_all_1  =rsum(ap08_a_mnt ap08_b_mnt ap08_c_mnt ap08_d_mnt ap08_e_mnt ap08_f_mnt ap08_g_mnt ap08_v_mnt)
	gen  total_waiting_time_all_1 =total_waiting_hour_all_1+(total_waiting_min_all_1/60)
	la var total_waiting_time_all_1 "total waiting time for all household member or friends, etc. Never try counts as 0"

	egen total_waiting_hour_hh_1 =rsum(ap08_a_hr ap08_b_hr)
	egen total_waiting_min_hh_1  =rsum(ap08_a_mnt ap08_b_mnt)
	gen total_waiting_time_hh_1  =total_waiting_hour_hh_1+(total_waiting_min_hh_1/60)
	la var total_waiting_time_hh_1 "total waiting time by head/spouse only. Never try counts as 0"

	gen total_waiting_time_all_2=total_waiting_time_all_1
	gen total_waiting_time_hh_2 =total_waiting_time_hh_1
	replace total_waiting_time_all_2=. if ever_try==3
	replace total_waiting_time_hh_2 =. if ever_try==3
	la var total_waiting_time_all_2 "total waiting time for all household member or friends, etc. Never try counts as missing"
	la var total_waiting_time_hh_2  "total waiting time by household head/spouse only. Never try counts as missing"

	//rename ap09 signup_success 
	//la var signup_success "Successfully signed up on the sign up day"
	//recode signup_success (3=0)

	/*in hours; all is counting everyone's waiting time in, 2:non show up = .*/
	keep hhid total_waiting_time_all_2
	
	tempfile costs
	save	`costs' // "codeddata/Endline/Self-Targeting.dta",replace


* showup and getbenefit
	use "originaldata\precoded\govt_crosswalk_baseline.dta",clear
	keep hhid showup  getbenefit
	tempfile crosswalk_new
	sa `crosswalk_new',replace

* kabgroup and urban
	use "originaldata\other\randomization.dta",clear
	keep hhea prov urban kecagroup kabgroup closesubtreatment bothspousesubtreatment maintreatment
	tempfile randomization
	sa      `randomization'
	
* poverty lines
	use "codeddata\baseline\matched_baseline.dta" , clear
	keep hhid povertyline1 verypoor_povertyline1 povertyline2 verypoor_povertyline2 
	tempfile povline
	save    `povline'

*average waiting time
	use `costs', clear
	//keep hhid total_waiting_time_all_2 
	gen hhea=substr(hhid,1,3)
	merge m:1 hhea using `randomization'
	drop if _merge==2
	drop 	_merge
	
	*only calculate average waiting time in either spouse OK subtreatment*
	keep if bothspousesubtreatment==0
	
	*trimming outliers*
	xtile temp_all=total_waiting_time_all_2, nq(100)
	egen temp1=min(temp_all)
	egen temp2=max(temp_all)
	replace total_waiting_time_all_2=. if temp_all==temp1 | temp_all==temp2 /*trim the top and bottom 1%*/
	drop temp*

	egen urban_close=group(urban closesubtreatment)
	
	*generate average waiting time for the four groups*
	bys urban_close: egen ave_waiting = mean(total_waiting_time_all_2)
	replace ave_waiting=ave_waiting*60 /*in minutes*/
	la var  ave_waiting "average waiting time by close subtreatment and urban/rural (min)"
	
	keep urban closesubtreatment urban_close ave_waiting
	duplicates drop 
	
	tempfile waiting
	sa 		`waiting'

* code distances, time cost and money cost, from baseline data

	use "originaldata\baseline\hh_ts.dta",clear

	replace tstype="1" if tstype=="a"
	replace tstype="2" if tstype=="b"

	destring tstype,replace
	drop ts02_v
	reshape wide ts01 ts02 ts03 ts04, i(hhid) j(tstype)

	rename ts011 distance_vill_rep
	rename ts012 distance_kec_rep
	rename ts021 transportation_vill
	rename ts022 transportation_kec
	rename ts031 time_vill_rep
	rename ts032 time_kec_rep
	rename ts041 money_vill_rep
	rename ts042 money_kec_rep

	label variable distance_vill_rep   "reported distance to village"
	label variable distance_kec_rep    "reported distance to kec"
	label variable transportation_vill "type of transportation often used to travel to village"
	label variable transportation_kec  "type of transportation often used to travel to kec"
	label variable time_vill_rep       "reported time to travel to village"
	label variable time_kec_rep        "reported time to travel to kec"
	label variable money_vill_rep      "reported money to travel to village"
	label variable money_kec_rep       "reported money to travel to kec"
	
	tempfile dist_baseline
	save    `dist_baseline',replace

* number of hours worked by the household in a month
	use "originaldata\baseline\hh_ar2",clear
	*tab ar07 /*types of primary activity*/

	*tab ar09 /*number of hours per day on primary activity*/
				/*Cut off at 18 hours.*/
	replace ar09=. if ar09>18

	*tab ar11 /*types of secondary activity*/

	*tab ar13 /*number of hours per day on secondary activity*/
				/*Cut off at 18 hours.*/
	replace ar13=. if ar13>18
	
	replace ar13=0 if ar11==96 | ar11==6 | ar11==10 | ar11==11 | ar11==.
	replace ar09=0 if ar07==6 | ar07>=10 

	bys hhid: egen hr_primary_perday1  =total(ar09), missing
	bys hhid: egen hr_secondary_perday1=total(ar13), missing

	bys hhid: egen hr_primary_perday  =max(hr_primary_perday1)
	bys hhid: egen hr_secondary_perday=max(hr_secondary_perday1)

	duplicates drop hhid, force
	gen totworkhr_month=(hr_primary_perday+hr_secondary_perday)*30
	la var totworkhr_month "total hours at work per month"
	keep hhid hr_primary_perday hr_secondary_perday totworkhr_month

	tempfile workhour
	save    `workhour',replace

/*monthly total household consumption data*/
	use "codeddata\baseline\consumption",clear
	keep hhid hhconsumption consumption hhsize /*total monthly expenditure of household; per capita monthly consumption in thousand rupees*/
	gen hhconsumption_day = hhconsumption/30	
	gen consumption_day   = consumption/30
		label variable hhconsumption_day "total household daily consumption in Rp"
		label variable consumption_day "daily per capita consumption in Rp"
	gen logconsumption = log(consumption)
		la var logconsumption "ln(per capita consumption)"
	tempfile consumption
	save 	`consumption'

/*information on kids for calculating true benefit*/
	use "originaldata\baseline\hh_ar2",clear
	gen     count_inprimarysch=0
	replace count_inprimarysch=1 if ar19==1 & ar17==2
	la var  count_inprimarysch "number of children in primary school"
	gen     count_inmiddlesch=0
	replace count_inmiddlesch=1 if ar19==1 & ar17==3
	la var  count_inprimarysch "number of children in middle school"
	collapse (sum) count_inprimarysch count_inmiddlesch, by(hhid)
	tempfile childeduc
	save    `childeduc'

/*have child*/
	use "originaldata\baseline\hh_kp1",clear
	replace kp10=0 if kp10==3
	replace kp01=0 if kp01==3
	rename kp10 havechild
	la var havechild "binary; 1 if have a child"
	rename kp01 pregnancy
	la var pregnancy "binary; 1 if pregnant"
	tempfile hh_kp1
	save    `hh_kp1'

*************
*** Start ***
*************

forv smallsample = 0/1 {
	u `dist_baseline', clear

	gen hhea=substr(hhid,1,3)

	merge m:1 hhea using `randomization'
	assert _merge==3
	drop _merge

	merge 1:1 hhid using `consumption'
	assert _merge==3
	drop _merge

	merge 1:1 hhid using `workhour'
	assert _merge==3
	drop _merge

	merge 1:1 hhid using `childeduc'
	assert _merge==3
	drop _merge

	merge 1:1 hhid using `hh_kp1'
	assert _merge==3
	drop _merge

	merge 1:1 hhid using `crosswalk_new'
	assert _merge==3
	drop _merge

	merge 1:1 hhid using `povline'
	assert _merge!=2 //not in hybrid
	drop _merge

	egen urban_close=group(urban closesubtreatment)
	merge m:1 urban_close using `waiting'
	drop _merge

	merge 1:1 hhid using "codeddata\baseline\coding_suseti_pmt.dta", keepusing(pcexppred PMTSCORE)
	assert _merge==3
	drop _merge
	
	* Urban/Rural label
	la def urban_lab 1 "urban" 0 "rural", replace
	la val urban urban_lab	

	* this analysis on selftargeting treatment only
	keep if maintreatment==2
	
	* For small sample version: duplicate households and re-assign
	if(`smallsample'==1){
		drop if closesubtreatment==1
		drop closesubtreatment
		expand 2, generate(closesubtreatment)
	}

	*****************
	** more coding **
	*****************

	* wage rate computed as total household expenditure per month, divided by total hours worked per month
		gen wagerate=hhconsumption/totworkhr_month
		
	* calculating true benefits
		gen hh_benefit_yly=200000 /*baseline*/
			replace hh_benefit_yly=hh_benefit_yly+800000 if havechild==1|pregnancy==1
			replace hh_benefit_yly=hh_benefit_yly+400000 if count_inprimarysch > 0 & count_inprimarysch < .
			replace hh_benefit_yly=hh_benefit_yly+800000 if count_inmiddlesch > 0 & count_inmiddlesch < .
			replace hh_benefit_yly=600000 if hh_benefit_yly<600000
			replace hh_benefit_yly=2200000 if hh_benefit_yly>2200000
			la var hh_benefit_yly "yearly HH benefit"
			gen hh_benefit_mly = hh_benefit_yly/12
			la var hh_benefit_mly "monthly HH benefit"
		gen benefit = hh_benefit_mly/hhsize
			la var benefit "monthly per capita benefit"

		sort urban kabgroup
		egen kab_urban = group(urban kabgroup)
				
		replace distance_kec_rep=. if distance_kec_rep>=998
		replace time_kec_rep    =. if time_kec_rep    ==998
		replace money_vill_rep  =. if money_vill_rep  ==999998
		replace money_kec_rep   =. if money_kec_rep   ==999998

		gen     distfar_rep=distance_vill_rep if urban==0
		replace distfar_rep=distance_kec_rep  if urban==1 
			la var  distfar_rep "reported distance to far distance (to kec if urban, to village if rural)"

		gen     distnear_rep=0                 if urban==0
		replace distnear_rep=distance_vill_rep if urban==1
			la var  distfar_rep "reported distance to near distance (to village if urban, zero if rural)"

		gen     timefar_rep=time_vill_rep*2+ave_waiting if urban==0 & closesubtreatment==0 /*rural to village, two way and wait time*/
		replace timefar_rep=time_kec_rep*2 +ave_waiting if urban==1 & closesubtreatment==0 /*urban to subdistrict, two way and wait time*/
			la var timefar_rep "total time to receive benefit: not close treatment (minutes)"
			
		gen     timenear_rep=time_vill_rep*2+ave_waiting if urban==1 & closesubtreatment==1 /*urban to village, two way and wait time*/
		replace timenear_rep=0              +ave_waiting if urban==0 & closesubtreatment==1 /*rural to neighborhood, two way and wait time*/
			la var timenear_rep "total time to receive benefit: close treatment (minutes)"

		gen     time_rep = timenear_rep if closesubtreatment==1
		replace time_rep = timefar_rep  if closesubtreatment==0
			la var time_rep "total time to receive benefit (minutes)"

		gen     traveltimefar=time_vill_rep if urban==0 /*rural to village, one way*/
		replace traveltimefar=time_kec_rep  if urban==1 /*urban to subdistrict, one way*/
			la var traveltimefar "reported travel time: far location (minutes)"

		gen     traveltimenear=time_vill_rep if urban==1 /*urban to village, one way*/
		replace traveltimenear=0             if urban==0 /*rural to neighborhood, one way*/
			la var traveltimenear "reported travel time: close location (minutes)"

		gen     moneyfar_rep=money_vill_rep*2 if urban==0 /*rural to village, two way*/
		replace moneyfar_rep=money_kec_rep*2  if urban==1 /*urban to subdistrict, two way*/

		gen     moneynear_rep=money_vill_rep*2 if urban==1 /*urban to village, two way*/
		replace moneynear_rep=0                if urban==0 /*rural to neighborhood, two way*/

		* create single distance variable for actual distance, cost, time, etc.
		gen distance = distfar_rep if closesubtreatment==0 
			replace distance = distnear_rep if closesubtreatment==1 
			replace distance = 0 if urban==0 & closesubtreatment==1 
			* drop outliers
			replace distance = . if distance>20
			la var distance "reported distance to registration place (no outliers)"	


		/* Predict money and time costs using quadratic in distance 
			for total cost, cost if >3km, and cost if >6km */
			xtile cquint = consumption, n(5)
				la var cquint "Consumption Quintile"
				
			/* Distance to kec (far subtreatment if urban) */	
			g dist_kec = distance_kec_rep if distance_kec_rep<20 | urban==0
			g dist_kec_2 = dist_kec^2
			local var_list = "money_kec time_kec"
			foreach var of local var_list {
				cap gen `var'_smth = .
				cap gen `var'_smth_quint = .
				cap gen `var'_smth_quint_3k_mc = .
				cap gen `var'_smth_quint_6k_mc = .
				forvalues i = 1/1 {
					* Predict Values
					reg `var'_rep dist_kec dist_kec_2 if urban==`i'
					replace `var'_smth = _b[_cons]+_b[dist_kec]*(dist_kec)+_b[dist_kec_2]*((dist_kec)^2) if urban==`i'
					
					forvalues j = 1(1)5 {
						* Predict Values
						reg `var'_rep dist_kec dist_kec_2 if urban==`i' & cquint==`j'
						replace `var'_smth_quint       = _b[_cons]+_b[dist_kec]*(dist_kec  )+_b[dist_kec_2]*(dist_kec^2    )                  if urban==`i' & cquint==`j'
						replace `var'_smth_quint_3k_mc = _b[_cons]+_b[dist_kec]*(3+dist_kec)+_b[dist_kec_2]*((3+dist_kec)^2)-`var'_smth_quint if urban==`i' & cquint==`j'
						replace `var'_smth_quint_6k_mc = _b[_cons]+_b[dist_kec]*(6+dist_kec)+_b[dist_kec_2]*((6+dist_kec)^2)-`var'_smth_quint if urban==`i' & cquint==`j'
					}
				}
			}
			
			/* Distance to village (far subtreatment if rural, close subtreatment if urban */
			g dist_vil = distance_vill_rep if distance_vill_rep<30
			g dist_vil_2 = dist_vil^2
			local var_list = "money_vill time_vill"
			foreach var of local var_list {
				cap gen `var'_smth = .
				cap gen `var'_smth_quint = .
				cap gen `var'_smth_quint_3k_mc = .
				cap gen `var'_smth_quint_6k_mc = .
				forvalues i = 0/1 {
					* Predict Values
					reg `var'_rep dist_vil dist_vil_2 if urban==`i'
					replace `var'_smth = _b[_cons]+_b[dist_vil]*(dist_vil)+_b[dist_vil_2]*((dist_vil)^2) if urban==`i'
							
					forvalues j = 1(1)5 {
						* Predict Values
						reg `var'_rep dist_vil dist_vil_2 if urban==`i' & cquint==`j'
						replace `var'_smth_quint       = _b[_cons]+_b[dist_vil]*(dist_vil  )+_b[dist_vil_2]*((dist_vil  )^2)                  if urban==`i' & cquint==`j'
						replace `var'_smth_quint_3k_mc = _b[_cons]+_b[dist_vil]*(3+dist_vil)+_b[dist_vil_2]*((3+dist_vil)^2)-`var'_smth_quint if urban==`i' & cquint==`j'
						replace `var'_smth_quint_6k_mc = _b[_cons]+_b[dist_vil]*(6+dist_vil)+_b[dist_vil_2]*((6+dist_vil)^2)-`var'_smth_quint if urban==`i' & cquint==`j'
					}
				}	
			}
			
			* Place a floor of zero for all the marginal costs of distance
			foreach v of varlist *mc {
				replace `v' = 0 if `v'<0
			}
			
		gen totcost_far=wagerate*timefar_rep/60+moneyfar_rep if closesubtreatment==0
			la var totcost_far "total cost (wage*time+monetary cost): not close treatment"
		gen totcost_near=wagerate*timenear_rep/60+moneynear_rep if closesubtreatment==1
			la var totcost_near "total cost (wage*time+monetary cost): close treatment"
			
		/* Actual and predicted total costs */
		
			* near rural
			gen totcost_pc =      (wagerate*(ave_waiting)/60)/hhsize                                                              if closesubtreatment==1 & urban==0	
			gen totcost_smth_pc = (wagerate*(ave_waiting)/60)/hhsize                                                              if closesubtreatment==1 & urban==0
			gen totcost_3k_pc =   (wagerate*(2*time_vill_smth_quint_3k_mc+ave_waiting)/60 + money_vill_smth_quint_3k_mc*2)/hhsize if closesubtreatment==1 & urban==0
			gen totcost_6k_pc =   (wagerate*(2*time_vill_smth_quint_6k_mc+ave_waiting)/60 + money_vill_smth_quint_6k_mc*2)/hhsize if closesubtreatment==1 & urban==0

			* far rural
			replace totcost_pc =      (wagerate*(2*time_vill_rep+ave_waiting)/60 + money_vill_rep*2)/hhsize                                                            if closesubtreatment==0 & urban==0	
			replace totcost_smth_pc = (wagerate*(2*time_vill_smth+ave_waiting)/60 + money_vill_smth*2)/hhsize                                                          if closesubtreatment==0 & urban==0
			replace totcost_3k_pc =   (wagerate*(2*(time_vill_rep+time_vill_smth_quint_3k_mc)+ave_waiting)/60 + (money_vill_rep+money_vill_smth_quint_3k_mc)*2)/hhsize if closesubtreatment==0 & urban==0
			replace totcost_6k_pc =   (wagerate*(2*(time_vill_rep+time_vill_smth_quint_6k_mc)+ave_waiting)/60 + (money_vill_rep+money_vill_smth_quint_6k_mc)*2)/hhsize if closesubtreatment==0 & urban==0
			
			* near urban
			replace totcost_pc =      (wagerate*(2*time_vill_rep+ave_waiting)/60 + money_vill_rep*2)/hhsize                                                            if closesubtreatment==1 & urban==1
			replace totcost_smth_pc = (wagerate*(2*time_vill_smth+ave_waiting)/60 + money_vill_smth*2)/hhsize                                                          if closesubtreatment==1 & urban==1
			replace totcost_3k_pc =   (wagerate*(2*(time_vill_rep+time_vill_smth_quint_3k_mc)+ave_waiting)/60 + (money_vill_rep+money_vill_smth_quint_3k_mc)*2)/hhsize if closesubtreatment==1 & urban==1
			replace totcost_6k_pc =   (wagerate*(2*(time_vill_rep+time_vill_smth_quint_6k_mc)+ave_waiting)/60 + (money_vill_rep+money_vill_smth_quint_6k_mc)*2)/hhsize if closesubtreatment==1 & urban==1

			* far urban
			replace totcost_pc =      (wagerate*(2*time_kec_rep+ave_waiting)/60 + money_kec_rep*2)/hhsize                                                          if closesubtreatment==0 & urban==1
			replace totcost_smth_pc = (wagerate*(2*time_kec_smth+ave_waiting)/60 + money_kec_smth*2)/hhsize                                                        if closesubtreatment==0 & urban==1
			replace totcost_3k_pc =   (wagerate*(2*(time_kec_rep+time_kec_smth_quint_3k_mc)+ave_waiting)/60 + (money_kec_rep+money_kec_smth_quint_3k_mc)*2)/hhsize if closesubtreatment==0 & urban==1
			replace totcost_6k_pc =   (wagerate*(2*(time_kec_rep+time_kec_smth_quint_6k_mc)+ave_waiting)/60 + (money_kec_rep+money_kec_smth_quint_6k_mc)*2)/hhsize if closesubtreatment==0 & urban==1
			
			* labels
			la var totcost_pc      "per capita cost of travel to registration"
			la var totcost_smth_pc "quad. est of per cap travel cost to registration by density"
			la var totcost_3k_pc   "per cap travel cost to registration by density: 3 km more distance"
			la var totcost_6k_pc   "per cap travel cost to registration by density: 6 km more distance"
		
		
		/* Moneycost calculation */

			* near rural
			gen moneycost = 0 										if closesubtreatment==1 & urban==0
			gen moneycost_smth = 0 									if closesubtreatment==1 & urban==0
			gen moneycost_3k = money_vill_smth_quint_3k_mc*2/hhsize if closesubtreatment==1 & urban==0
			gen moneycost_6k = money_vill_smth_quint_6k_mc*2/hhsize if closesubtreatment==1 & urban==0
			
			* far rural
			replace moneycost =      money_vill_rep*2/hhsize 							  if closesubtreatment==0 & urban==0
			replace moneycost_smth = money_vill_smth*2/hhsize 							  if closesubtreatment==0 & urban==0
			replace moneycost_3k =  (money_vill_rep+money_vill_smth_quint_3k_mc)*2/hhsize if closesubtreatment==0 & urban==0
			replace moneycost_6k =  (money_vill_rep+money_vill_smth_quint_6k_mc)*2/hhsize if closesubtreatment==0 & urban==0
			
			* near urban
			replace moneycost =      money_vill_rep*2/hhsize 							  if closesubtreatment==1 & urban==1
			replace moneycost_smth = money_vill_smth*2/hhsize 						      if closesubtreatment==1 & urban==1
			replace moneycost_3k =  (money_vill_rep+money_vill_smth_quint_3k_mc)*2/hhsize if closesubtreatment==1 & urban==1
			replace moneycost_6k =  (money_vill_rep+money_vill_smth_quint_6k_mc)*2/hhsize if closesubtreatment==1 & urban==1
			
			* far urban
			replace moneycost =      money_kec_rep*2/hhsize 							if closesubtreatment==0 & urban==1
			replace moneycost_smth = money_kec_smth*2/hhsize 							if closesubtreatment==0 & urban==1
			replace moneycost_3k =  (money_kec_rep+money_kec_smth_quint_3k_mc)*2/hhsize if closesubtreatment==0 & urban==1
			replace moneycost_6k =  (money_kec_rep+money_kec_smth_quint_6k_mc)*2/hhsize if closesubtreatment==0 & urban==1
			
			

	************************
	* Estimate mu function * 
	************************
		
	* probability of receiving benefit conditional on applying, income, kabgroup, and pop density (urban/rural)

	/*lambda function with FE - we do not use this*/
		xi: probit getbenefit logconsumption i.kab_urban if showup==1 
		predict probit_prediction_sample 
		
		gen reg_logcon = _b[logconsumption]
		gen reg_const  = _b[_cons]
		
		gen FE=0
		forvalues k = 2/10{
			* capture error because _Ikab_urban_10 doesn't exist for small sample
			cap replace FE = FE + _b[_Ikab_urban_`k'] if kab_urban == `k'
		}
		

	/*lambda function without FE*/
		probit getbenefit logconsumption if showup==1 
		matrix A=e(b)
		
		gen reg_nofe_logcon = _b[logconsumption]
		gen reg_nofe_const  = _b[_cons]


	/*mu function*/
		xi: probit getbenefit PMTSCORE i.kab_urban if showup==1

		gen reg_pmt2 = _b[PMTSCORE]
		gen reg_const2  = _b[_cons]
		
		gen FE2=0
		forvalues k = 2/10{
			* capture error because _Ikab_urban_10 doesn't exist for small sample
			cap replace FE2 = FE2 + _b[_Ikab_urban_`k'] if kab_urban == `k'
		}

		
	* save version of costs used in cost table	
	if( `smallsample'==0){	
	preserve
		rename distance distance_rep
		keep hhid hhea benefit  hh_benefit_mly maintreatment closesubtreatment ///
			 totcost_pc ave_waiting wagerate ///
			 hhsize totcost_smth_pc totcost_3k_pc totcost_6k_pc distance_rep consumption
		save "codeddata\midline\costs.dta", replace
	restore
	}
		
		
	* adjust cost in the subtreatment where both spouses need to attend
	* however, it was not always the case that both showed up at the application site
	* the government data reveals that:
	*   in 61.61% of cases both showed up
	*   in 29.77% only one showed up (and 98% brought a letter)
	*   in  8.62% the hhd head did not have a spouse
	*
	* hence, the costs should on average be multiplied by 1.6161
	foreach v of varlist *totcost* moneycost* {
		replace `v' = `v'*1.6161 if bothspousesubtreatment==1
		
		}

	* save 
	destring hhid, replace
	ren PMTSCORE pmtscore
	ren distance distt
	sort consumption


	if( `smallsample'==0){
		cap mkdir "codeddata\matlab"
		outsheet hhid hhea consumption totcost_pc totcost_smth_pc totcost_3k_pc totcost_6k_pc benefit showup closesubtreatment urban distt ///
			ave_waiting hhsize wage reg_const reg_logcon FE reg_const2 reg_pmt2 FE2 reg_nofe_const reg_nofe_logcon moneycost* pmtscore ///
			getbenefit ///
			using "codeddata\matlab\MATLAB_Input.csv" if maintreatment==2 & mi(distt, consumption, totcost_pc, benefit, showup, closesubtreatment, urban, probit_prediction_sample )==0, ///
			comma noquote nolab replace
	}
	else{
		gen keep_obs = mi(distt, consumption, totcost_pc, benefit, showup, closesubtreatment, urban, probit_prediction_sample)==0
		bys hhid: egen temp = max(keep_obs)
		replace keep_obs = temp
		drop temp

		outsheet hhid hhea consumption totcost_pc totcost_smth_pc totcost_3k_pc totcost_6k_pc benefit showup closesubtreatment urban distt ///
			ave_waiting hhsize wage reg_const reg_logcon FE reg_const2 reg_pmt2 FE2 reg_nofe_const reg_nofe_logcon moneycost* pmtscore ///
			getbenefit ///
			using "codeddata\matlab\MATLAB_Input_small_sample.csv" if keep_obs==1, ///
			comma noquote nolab replace
	}	
}
* last line :)

