/* MASTER do-file for:
SELF-TARGETING: EVIDENCE FROM A FIELD EXPERIMENT IN INDONESIA
VIVI ALATAS, ABHIJIT BANERJEE, REMA HANNA,
BENJAMIN A. OLKEN, RIRIN PURNAMASARI, AND MATTHEW WAI-POI
Last Modified 14 Nov 2014 */

clear all
pause on

global STfolder = "<INPUT FOLDER PATH HERE>"
local STfolder = "$STfolder"

cd "`STfolder'dofiles\"
						   
*******************
*** Coding
*******************

* coding SUSETI data 
do "`STfolder'dofiles\coding\01 coding baseline.do"  
						/* Use: originaldata\Baseline\hh_ks1, hh_ks2, hh_lk, hh_ar1, hh_ar2, k_data, k_cp1, hh_ts, hh_kr1, hh_hr1, hh_hr2, 
								originaldata\others\wilcah 
								codeddata\others\randomization\randomizationresults_111012 
						  Create: codeddata\Baseline\location, consumption, hhhead, pctagriculture, rthead, distance, hhcharacteristic, hh_ar2, hhasset, 
								  codeddata\others\randomization\randomizationresults_111012_modified
						*/		


* Calculate pmt score from suseti variables 						   
do "`STfolder'dofiles\coding\02 coding suseti pmt.do"		
						/* Use: codeddata\baseline\hhhead.dta", clear
								codeddata\baseline\consumption.dta
								codeddata\baseline\hhcharacteristic.dta
								codeddata\baseline\hhasset.dta
								codeddata\baseline\hh_ar2.dta
								codeddata\baseline\distance_kec.dta
								originaldata\other\randomization
								originaldata\precoded\coding_podes08.dta
								originaldata\other\PMT_weights.dta
						   Create codeddata\baseline\coding_suseti_pmt.dta */

* match baseline survey data with government showup and getbenefit data 
do "`STfolder'dofiles\coding\03 matching government data.do"	
						/*Use: originaldata\precoded\govt_crosswalk_baseline.dta
							   originaldata\other\randomization.dta
							   originaldata\baseline\k_data.dta
							   codeddata\baseline\coding_suseti_pmt, hhhead, consumption, hh_ar2
						 Create codeddata\baseline\matched_baseline.dta */
						
* coding midline consumption and match with government showup and getbenefit data
do "`STfolder'dofiles\coding\04 coding midline.do"  
                        /*Use: originaldata\endline\hh_cov, hh_rp1
							   originaldata\precoded\govt_crosswalk_midline.dta
							   originaldata\other\randomization.dta
						Create: codeddata\midline\matched_midline.dta*/


do "`STfolder'dofiles\coding\05 matlab input.do"
						/*Use: originaldata\midline\hh_ap1.dta 
						       originaldata\other\govt_crosswalk_baseline.dta
							   originaldata\other\randomization.dta
							   codeddata\baseline\matched_baseline.dta
							   originaldata\baseline\hh_ts.dta
							   originaldata\baseline\hh_ar2
							   codeddata\baseline\consumption
							   originaldata\baseline\hh_ar2
							   originaldata\baseline\hh_kp1
							   codeddata\baseline\coding_suseti_pmt.dta
						Create: codeddata\matlab\MATLAB_Input.csv
								codeddata\matlab\MATLAB_Input_small_sample.csv
						*/
						
	
*******************
*** MAIN TABLES
*******************

* Table 1: no do-file

* Table 2: no do-file

* Table 3: no do-file

* Table 4: Probability of Showing Up as a Function of the Observed and Unobserved Components of Baseline Log Per capita Consumption
do "`STfolder'dofiles\analysis\Table 4.do"
/* Input: codeddata\baseline\matched_baseline.dta
   Ouput: tables\Table 4
*/   

* Table 5: Experimental Comparison of Targeting under Self-Targeting and Automatic Screening Treatments
run "`STfolder'dofiles\analysis\Table 5.do"
/* Input: codeddata\baseline\matched_baseline.dta
		  codeddata\midline\matched_midline.dta
   Ouput: tables\Table 5
*/ 

* Table 6: Comparison of Targeting under Self-Selection and Hypothetical Universal Automatic Targeting using Baseline Data
run "`STfolder'dofiles\analysis\Table 6.do"
/* Input: codeddata\Baseline\matched_baseline.dta
   Ouput: tables\Table 6
*/ 

* Table 7: 
run "`STfolder'dofiles\analysis\Table 7.do"
/* Input: codeddata\Baseline\matched_baseline.dta
   Ouput: tables\Table 7
*/ 


*****************************
* * Run GMM analysis: Tables 8,9,10
*****************************	

	pause on
	pause "run in MATLAB dofiles\matlab\GMM_master.m"
	/* Input: MATLAB_Input.csv
			  MATLAB_Input_small_sample.csv
	   Output: MATLAB_Estimates_main_d**.csv    
			   ** corresponds to the value of the annual discount factor: d=0.82 = 1/irate, d=0.50 or d=0.95
			   bootstrap_**\bootstrap_[something]_d**.csv
			   MATLAB_showuphat_small_sample.csv
			   MATLAB_showuphat.csv
			   MATLAB_goodness_fit.csv
			   MATLAB_GS_lambda_scaled.csv

Note 1: the format of the files MATLAB_Estimates_main_d**.csv is as follows:
* each row corresponds to a set of initial values
* columns 1, 4, 7, 10 and 13 are the initial parameters v_epsilon, sigma_epsilon, alpha, gamma, pi
* columns 2, 5, 8, 11 and 14 are the first stage GMM estimated paramaters 
* columns 3, 6, 9, 12 and 15 are the second stage GMM estimated parameters
* column 17 indicates the second stage objective function corresponding to that row
* column 20 is equal to 1 iff the row contains the estimated parameters. It corresponds to the final estimated parameters 

Note 2: the format of the files boostrap_**\bootstrap_estimates_d**.csv is as follows:
* one each line, columns 3,6,9,12 and 15 report the estimated parameters for that bootstrap iteration
	
	*/
	
* Table 8: Estimated Parameter Values for the Model 
	/* 
	Use estimates in MATLAB_Estimates_main_d82.csv.
	Use standard errors computed from boostrap_82\bootstrap_estimates_d82.csv (outputed by GMM_master.m)
	*/	

* Online Appendix Table C.16. Estimated Parameters Values for the Model (Discount Rate Robustness Check)
	/* 
	for **= 50 and **=95:
	Use estimates in MATLAB_Estimates_main_d**.csv.
	Use standard errors computed from boostrap_**\bootstrap_estimates_d**.csv (outputed by GMM_master.m)
	*/
	
* Online Appendix Table C.17. The Sensitivity of Estimated Parameters to Moment Values
	/*
	output from codeddata\matlab\MATLAB_GS_lambda_scaled.csv (transpose)
	*/

* Online Appendix Table C.22
	/* 
	output from codeddata\matlab\MATLAB_goodness_fit.csv
	*/ 
	
	

* Table 9:                   Modeled Effects of Time and Distance Costs on Show Up Rates
* Online Appendix Table C19. Modeled Effects of Time and Distance Costs on Show Up Rates (Corrected for Small Sample Differences)
* Online Appendix Table C20. Modeled Effects of the Fraction of Sophisticated Households

run "`STfolder'dofiles\analysis\Table 9.do"
/* Input: codeddata\Baseline\matched_baseline.dta
		  codeddata\Matlab\MATLAB_showuphat.csv
		  codeddata\Matlab\MATLAB_showuphat_small_sample.csv
   Ouput: tables\Table 9
		  tables\Online Appendix C19
		  tables\Online Appendix C20
*/ 

* Table 10: Impact of Alternative Targeting Approaches on the Poverty Gap
run "`STfolder'dofiles\analysis\Table 10.do"
/* Input: codeddata\baseline\matched_baseline.dta
		  originaldata\baseline\hh_kp1
		  originaldata\baseline\hh_ar2
		  codeddata\Baseline\coded_baseline_partV.dta
		  codeddata\midline\costs.dta
		  codeddata\Matlab\MATLAB_showuphat.csv
   Ouput: tables\Table 10
*/ 


*******************
*** MAIN FIGURES
*******************

* Figure 1: Probability of Obtaining Benefits vs. Log Per Capita Consumption and PMT score
run "`STfolder'dofiles\analysis\Figure 1.do"
/* Input: codeddata\Baseline\matched_baseline.dta
   Ouput: figures\Figure 1a
		  figures\Figure 1b
*/ 

* Figure 2. Show Up Rates Versus Log Per Capita Consumption
* Figure 3. Show Up Rates Versus Observable and Unobservable Components of Log Per Capita Consumption
run "`STfolder'dofiles\analysis\Figure 2-3.do"
/* Input: data\codeddata\baseline\matched_baseline.dta
   Ouput: figures\Figure 2
		  figures\Figure 3a
		  figures\Figure 3b
*/ 


* Figure 4: Experimental Comparison of Self-Targeting and Automatic Screening Treatments
run "`STfolder'dofiles\analysis\Figure 4.do"
/* Input: data\codeddata\baseline\matched_baseline.dta
   Ouput: figures\Figure 4a
		  figures\Figure 4b
*/ 

* Figure 5: Comparison of Self-Selection and Hypothetical Universal Automatic Targeting
run "`STfolder'dofiles\analysis\Figure 5.do"
/* Input: data\codeddata\baseline\matched_baseline.dta
   Ouput: figures\Figure 5a
		  figures\Figure 5b
*/ 

* Figure 6: Cost of Applying by Per Capita Consumption
run "`STfolder'dofiles\analysis\Figure 6.do"
/* Input: codeddata\midline\costs.dta
   Ouput: figures\Figure 6
*/ 


*******************
*** Appendix A
*******************

* Appendix Table A.1. 
* no do-file
* results are from Online Appendix Tables C.8, C.10, C.11, C.12 and C.13


*******************
*** Online Appendix C - Tables
*******************

* Online Appendix Table C.1. Experiment Validation
run "`STfolder'dofiles\analysis\Online Appendix Table C1.do"
/* Input: originaldata\precoded\distances.dta
		  codeddata\baseline\hhhead.dta
		  codeddata\Baseline\coding_suseti_pmt.dta
		  codeddata\Baseline\consumption.dta
		  codeddata\Baseline\rthead.dta
		  codeddata\Baseline\distance.dta
		  codeddata\Baseline\pctagriculture.dta
		  originaldata\precoded\coding_podes08.dta
   Ouput: tables\Online Appendix Table C1 means.csv
		  tables\Online Appendix Table C1 diff noFE
		  tables\Online Appendix Table C1 diff FE
*/ 

* Online Appendix Table C.2. Probability of Showing Up as a Function of the Observed and Unobserved Components of Baseline Log Per Capita Consumption (OLS)
run "`STfolder'dofiles\analysis\Online Appendix Table C2.do"
/* Input: codeddata\baseline\matched_baseline.dta
   Ouput: tables\Online Appendix Table C2
*/ 

* Online Appendix Table C.3. Probability of Showing Up and Probability of being Pre-Screened as Functions of Consumption
run "`STfolder'dofiles\analysis\Online Appendix Table C3.do"
/* Input: codeddata\baseline\matched_baseline.dtaa
   Ouput: tables\Online Appendix Table C3
*/ 

* Online Appendix Table C.4. Factors Predicting Show Up (Logit)
* Online Appendix Table C.5. Factors Predicting Show Up (OLS)
run "`STfolder'dofiles\analysis\Online Appendix Table C4-5.do"
/* Input: originaldata\Baseline\hh_pm2.dta
		  originaldata\Baseline\hh_pm3.dta
		  originaldata\Baseline\hh_krt.dta
		  originaldata\baseline\hh_ksr1.dta
		  originaldata\baseline\hh_ge.dta
		  originaldata\baseline\hh_sw.dta
		  originaldata\baseline\hh_ar2.dta
		  codeddata\baseline\matched_baseline.dta
   Ouput: tables\Online Appendix Table C45_*
*/ 

* Online Appendix Table C.6. Experimental Comparison of Targeting under Self-Targeting and Automatic Screening Treatments (OLS)
run "`STfolder'dofiles\analysis\Online Appendix Table C6.do"
/* Input: codeddata\baseline\matched_baseline.dta
		  codeddata\midline\matched_midline.dta
   Ouput: tables\Online Appendix Table 6a
		  tables\Online Appendix Table 6b
*/ 

* Online Appendix Table C.7. Factors interacted with Self-Targeting treatment predicting benefit receipt (Logit)
run "`STfolder'dofiles\analysis\Online Appendix Table C7.do"
/* Input: originaldata\Baseline\hh_pm2.dta
		  originaldata\Baseline\hh_pm3.dta
		  originaldata\Baseline\hh_krt.dta
		  originaldata\baseline\hh_ksr1.dta
		  originaldata\baseline\hh_ge.dta
		  originaldata\baseline\hh_sw.dta
		  originaldata\baseline\hh_ar2.dta
		  codeddata\baseline\matched_baseline.dta
   Ouput: tables\Online Appendix Table C7_*
*/ 

* Online Appendix Table C.8
run "`STfolder'dofiles\analysis\Online Appendix Table C8.do"
/* Input: codeddata\baseline\matched_baseline.dta
   Ouput: tables\Online Appendix Table 8
*/

* Online Appendix Table C.9 - C.13
run "`STfolder'dofiles\analysis\Online Appendix Table C9-13.do"
/* Input: codeddata\baseline\matched_baseline.dta
   Ouput: tables\Online Appendix Table 9
		  tables\Online Appendix Table 10
		  tables\Online Appendix Table 11
		  tables\Online Appendix Table 12
		  tables\Online Appendix Table 13
*/ 

* Online Appendix Table C.14. Experimental Results: Probability of Showing Up as a Function of Distance (OLS)
run "`STfolder'dofiles\analysis\Online Appendix Table C14.do"
/* Input: codeddata\baseline\matched_baseline.dta
   Ouput: tables\Online Appendix Table 14
*/ 

* Online Appendix Table C.15. Effect of Close Subtreatment on Distance
run "`STfolder'dofiles\analysis\Online Appendix Table C15.do"
/* Input: codeddata\baseline\matched_baseline.dta
		  originaldata\precoded\distances.dta
   Ouput: tables\Online Appendix Table 15a
          tables\Online Appendix Table 15b
		  tables\Online Appendix Table 15c
*/ 

* Online Appendix Table C.16-C.17
/* 
See GMM estimation.
*/ 

* Online Appendix Table C.18 Summary Statistics of Modeled Registration Costs
run "`STfolder'dofiles\analysis\Online Appendix Table C18.do"
/* Input: codeddata\midline\costs.dta
   Ouput: tables\Online Appendix Table 18
*/ 

* Online Appendix Table C.19 
* Online Appendix Table C.20 
/* 
See Table 9.
*/ 

* Online Appendix Table C.21 Experimental Results: Probability of Showing up as a Function of Opportunity Cost Treatment
run "`STfolder'dofiles\analysis\Online Appendix Table C21.do"
/* Input: codeddata\baseline\matched_baseline.dta
   Ouput: tables\Online Appendix Table 21
*/ 

* Online Appendix Table C.22
/* 
See GMM estimation.
*/ 

*******************
*** Online Appendix C - Figures
*******************

* Online Appendix Figure C.1 Break-even Discount Factor for Showing Up
run "`STfolder'dofiles\analysis\Online Appendix Figure C1.do"
/* Input: codeddata\midline\costs.dta
		  codeddata\baseline\hhhead.dta
		  codeddata\baseline\matched_baseline.dta
   Ouput: figures\Online Appendix Figure C1
*/ 

* Online Appendix Figure C.2 Comparison between Government and Baseline Data
run "`STfolder'dofiles\analysis\Online Appendix Figure C2.do"
/* Input: codeddata\baseline\matched_baseline.dta
   Ouput: figures\Online Appendix Figure C2
*/ 

* Online Appendix Figure C.3 
run "`STfolder'dofiles\analysis\Online Appendix Figure C3.do"
/* Input: codeddata\baseline\matched_baseline.dta
   Ouput: figures\Online Appendix Figure C3
*/

* Online Appendix Figure C.4 Model Fit and Counterfactuals
run "`STfolder'dofiles\analysis\Online Appendix Figure C4.do"
/* Input: codeddata\Matlab\MATLAB_showuphat.csv
		  codeddata\baseline\matched_baseline.dta
   Ouput: figures\Online Appendix Figure C4
*/
