% Compute Gentzkow Shapiro sensitivity measure
% Online Appendix Table C.16.

%clearvars -global

global t2folder
tempfolder = [t2folder 'data\codeddata\matlab\'];

%%%%%%%%%%%%%%%%%%%%%%%%%%
% Load bootstrapped standard errors 
% Calculate moment values
% Compute G/S sensitivity measure
%%%%%%%%%%%%%%%%%%%%%%%%

G = csvread([tempfolder 'MATLAB_GS_jacobian.csv']);
W = csvread([tempfolder 'MATLAB_GS_wmatrix.csv']);

%%%%%%%%%%%%%%%%%%%%%%%%%%
% Bootstrapped standard errors for moment values
% Import bootstrap results
%%%%%%%%%%%%%%%%%%%%%%%%%%%

eta_sd = 0.275;
delta_mom = 1;
irate = 1.22;
irm = 1/irate;
danual = 1/irate;
delta = danual*(1 + irm + irm^2 + irm^3 + irm^4 + irm^5);
    

    boot_estimates = csvread([tempfolder 'bootstrap_GS\bootstrap_estimates_GS_82.csv']);
    boot_samples   = csvread([tempfolder 'bootstrap_GS\bootstrap_samples_GS_82.csv']);

    n_boot = size(boot_samples,1);
    
    boot_moms = zeros(n_boot,20);

    for it=1:n_boot
       display(num2str(it));
       sample    = boot_samples(it,:);
       small_sample_dummy = 0;
       load_data(sample,small_sample_dummy);
       
       global lambda_con_true lambda_beta_true consumption
       
         mu_eps  = boot_estimates(it,3);
         sig_eps = boot_estimates(it,6);
         alpha   = boot_estimates(it,9);
         lambda_con_belief  = boot_estimates(it,12);
         lambda_beta_belief = boot_estimates(it,15);

         [ showup_hat, induced_lambda ] = showuphat(mu_eps, sig_eps, alpha, lambda_con_belief, lambda_beta_belief, eta_sd, delta);

         belief_lambda  = normcdf(lambda_con_belief+lambda_beta_belief*log(consumption));
         true_lambda    = normcdf(lambda_con_true  +lambda_beta_true  *log(consumption));

         temp = moments( showup_hat, true_lambda, belief_lambda, induced_lambda, delta_mom );
         boot_moms(it,:) = mean(temp,1);
    end

    % Compute standard devs of 
    boot_moms_std = std(boot_moms);
    boot_ests_std = std(boot_estimates(:,[3,6,9,12,15]));

% Calculate the Gentzkow-Shapiro sensitivity matrix

% Gentzkow Shapiro sensitivity parameter - NOT SCALED
Lambda = (G'*W*G)\G'*W;
csvwrite([tempfolder 'MATLAB_GS_lambda_notscaled.csv'],Lambda);

% Gentzkow Shapiro sensitivity parameter - SCALED
Lambdatilde = diag(boot_ests_std)\Lambda*diag(boot_moms_std);
csvwrite([tempfolder 'MATLAB_GS_lambda_scaled.csv'],Lambdatilde);

