% Estimate bootstrapped standard errors for the model using 
% a different set of momemnts (far and far-close). 
% Used in Online Appendix Table C.16

clearvars -global

global t2folder
tempfolder = [t2folder 'Experiment\Data\codeddata\Matlab\'];

% Import and Name Data From .csv File
load_data();

% load globals that we need
global consumption
if isempty(consumption)
    error('Did not lead data');
end

%% parameters
irate   = 1.22;
danual  = 1/irate; % alternatives: danual = 0.50 and = 0.95.
eta_sd  = 0.275;
N = size(consumption,1);
delta_mom = 1;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
rng(3797265); 
n_boot = 50; % Number of bootstrap iterations
passes = 50; % Number of passes (initial conditions) per iteration
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

rng_seed = 10000*rand(n_boot,1);

% store bootstrap subsample
boot_samples = zeros(n_boot,N);
% store estimated parameters 
params_boots = zeros(n_boot,20);
% store all passes for each iteration 
params_boots_all = zeros(n_boot*passes,20);
% store weighting matrices
weight_matrix = zeros(n_boot*20,20);

%showuphat_boots = zeros(size(consumption,1),n_boot); % Will store showup_hat induced by the parameters of each iteration here
time_boots = zeros(n_boot,1); % Save time taken here

for it=1:n_boot
tic
    % randomly draw index of individuals (with replacement) for bootstrap
    boot_sample = randsample(1:N,N,true); 
    boot_samples(it,:) = boot_sample; % save sample
 
    [W,p_all] = GMM_problem(delta_mom, danual, irate, eta_sd, passes, rng_seed(it), boot_sample);

    Fval_ss = p_all(:,17);
    [~, minindex] = min(Fval_ss);
    params_boots(it,:) = p_all(minindex,:);
    params_boots_all( (it-1)*passes + (1:passes),:) = p_all;
    weight_matrix( (it-1)*20 + (1:20),:) = W;
    
    sprintf('Bootstrap iteration: %i. Last iteration took %i sec.', it,toc)
    
    % write output so far (overwrite)
    temp = round(danual*100);
    csvwrite([tempfolder 'bootstrap_GS\bootstrap_estimates_GS_' num2str(temp) '.csv'],params_boots);
    csvwrite([tempfolder 'bootstrap_GS\bootstrap_allpasses_GS_' num2str(temp) '.csv'],params_boots_all);
    csvwrite([tempfolder 'bootstrap_GS\bootstrap_samples_GS_' num2str(temp) '.csv'],boot_samples);
    csvwrite([tempfolder 'bootstrap_GS\bootstrap_weight_matrix_GS_' num2str(temp) '.csv'],weight_matrix);
    
time_boots(it) = toc;    
end