% Calculate counterfactual showup_hat used in Tables 9 and 10, and 
% Online Appendix Table C.18

%clearvars -global

global t2folder
tempfolder = [t2folder 'data\codeddata\Matlab\'];
    
%%%%%%%%%%%%%%%%%%
% fixed parameters
%%%%%%%%%%%%%%%%%%

eta_sd = 0.275;
irate = 1.22;
danual = 1/irate;
irm    = 1/irate;
delta = danual*(1 + irm + irm^2 + irm^3 + irm^4 + irm^5);

%%%%%%%%%%%%%%%%%%
% Input parameters manually
% these are the baseline estimated parameters (danual = 1/irate)
%%%%%%%%%%%%%%%%%%

mu_eps        = -79681;	
sig_eps       = 59715;
alpha         = 0.5049;	
lambda_con_belief    = 8.0448;	
lambda_beta_belief   = -0.71673;

% full sample
sample = [];

for small_sample_dummy = 0:1

    % load full data
    load_data(sample,small_sample_dummy);
    global hhid quant_idx;

    % Column 1 is showup, Column 2 is showuphat
    [ showup_hat, ~ ] = showuphat(mu_eps, sig_eps, alpha, lambda_con_belief, lambda_beta_belief, eta_sd, delta);
    showup_table   = [table(hhid), table(quant_idx), table(showup_hat)];

    % Column 3 Half Standard Deviation of epsilon
    [ showup_hat_halfsd , ~ ] = showuphat(mu_eps, sig_eps/2, alpha, lambda_con_belief, lambda_beta_belief, eta_sd, delta);
    showup_table   = [showup_table, table(showup_hat_halfsd)];

    % Column 4 No epsilon variance
    [ showup_hat_noeps , ~ ] = showuphat(mu_eps, sig_eps/1e10, alpha, lambda_con_belief, lambda_beta_belief, eta_sd, delta);
    showup_table   = [showup_table, table(showup_hat_noeps)];

    %%% replace travel cost by same travel cost
    global totcost_smth_pc totcost_pc
    totcost_pc = totcost_smth_pc; %#ok<NASGU>

    % Column 5 no differential travel cost
    [ showup_hat_smthc , ~ ] = showuphat(mu_eps, sig_eps, alpha, lambda_con_belief, lambda_beta_belief, eta_sd, delta);
    showup_table   = [showup_table, table(showup_hat_smthc)];

    %%% reload data, and assume constanta MU and LAMBDA
    load_data(sample,small_sample_dummy);
    mean_mu = 0.0967742; % mean benefit receipt conditional on applying

    global mu_con_true mu_beta_true FE FE2;
    lambda_con_belief_cml = norminv(mean_mu);
    lambda_beta_belief_cml = 0;
    mu_con_true = norminv(mean_mu);
    mu_beta_true = 0;
    FE = FE*0;
    FE2 = FE2*0;

    % Column 6 (constant mu AND lambda, update from the previous draft)
    [ showup_hat_cml  , ~ ] = showuphat(mu_eps, sig_eps, alpha, lambda_con_belief_cml, lambda_beta_belief_cml, eta_sd, delta);
    showup_table   = [showup_table, table(showup_hat_cml)];

    
    if(small_sample_dummy==1)
        global close
        showup_table   = [showup_table, table(close)];        
        writetable(showup_table, [tempfolder 'MATLAB_showuphat_small_sample.csv']);

    else

        % Column 7: 3 extra km
        load_data(sample,small_sample_dummy);
        global totcost_pc totcost_3k_pc close
        totcost_pc = (1-close).*totcost_3k_pc + close.*totcost_pc;
        [ showup_hat_km3 , ~ ] = showuphat(mu_eps, sig_eps, alpha, lambda_con_belief, lambda_beta_belief, eta_sd, delta);
        showup_table   = [showup_table, table(showup_hat_km3)];

        % Column 8: 6 extra km
        load_data(sample,small_sample_dummy);
        global totcost_pc totcost_6k_pc close
        totcost_pc = (1-close).*totcost_6k_pc + close.*totcost_pc; 
        [ showup_hat_km6 , ~ ] = showuphat(mu_eps, sig_eps, alpha, lambda_con_belief, lambda_beta_belief, eta_sd, delta);
        showup_table   = [showup_table, table(showup_hat_km6)];

        % Column 9: 3x waiting time
        load_data(sample,small_sample_dummy);
        global totcost_pc hhsize close ave_waiting wagerate
        totcost_pc = totcost_pc + (1-close).*(2.*ave_waiting.*wagerate)./(hhsize.*60);
        [ showup_hat_3aw , ~ ] = showuphat(mu_eps, sig_eps, alpha, lambda_con_belief, lambda_beta_belief, eta_sd, delta);
        showup_table   = [showup_table, table(showup_hat_3aw)];

        % Column 10: 6x waiting time
        load_data(sample,small_sample_dummy);
        global totcost_pc hhsize close ave_waiting wagerate
        totcost_pc = totcost_pc + (1-close).*(5.*ave_waiting.*wagerate)./(hhsize.*60);
        [ showup_hat_6aw , ~ ] = showuphat(mu_eps, sig_eps, alpha, lambda_con_belief, lambda_beta_belief, eta_sd, delta);
        showup_table   = [showup_table, table(showup_hat_6aw)];


        % Column 11-12 alpha=0 (all-unsophisticated) and alpha=1 (all sophisticated)
        load_data(sample,small_sample_dummy);
        [ showup_hat_alpha0 , ~ ] = showuphat(mu_eps, sig_eps, 0, lambda_con_belief, lambda_beta_belief, eta_sd, delta);
        showup_table   = [showup_table, table(showup_hat_alpha0)];

        [ showup_hat_alpha1 , ~ ] = showuphat(mu_eps, sig_eps, 1, lambda_con_belief, lambda_beta_belief, eta_sd, delta);
        showup_table   = [showup_table, table(showup_hat_alpha1)];

        writetable(showup_table, [tempfolder 'MATLAB_showuphat.csv']);
    end

end