% Estimate main model using a different set of momemnts (far and
% (far-close). Used in Online Appendix Table C.16

%clearvars -global

global t2folder
tempfolder = [t2folder 'data\codeddata\Matlab\'];

% G/S specification with far-close moments 
irate   = 1.22;
danual  = 1/irate;
irm = 1/irate;
delta = danual*(1 + irm + irm^2 + irm^3 + irm^4 + irm^5);
eta_sd  = 0.275;
delta_mom = 1; % <-- turned on for far-close moments
passes = 100;

% full sample
sample = [];

rng_seed = 945739485;

[W,p_all] = GMM_problem(delta_mom, danual, irate, eta_sd, passes, rng_seed,sample);

% get minimum
Fval_ss = p_all(:,17);
[~, minindex] = min(Fval_ss);

csvwrite([tempfolder 'MATLAB_Estimates_GS.csv'],p_all);

%%%%%%%%%%%%%%%%%%%%%%%%
% Compute numerical Jacobian at the optimum
%%%%%%%%%%%%%%%%%%%%%%%%

% optimal estimated parameters
% Point at which Jacobian needs to be estimated            
params_in(1) = p_all(minindex,3);  % mu_eps
params_in(2) = p_all(minindex,6);  % sig_eps
params_in(3) = p_all(minindex,9);  % alpha     
params_in(4) = p_all(minindex,12); % lambda_con 
params_in(5) = p_all(minindex,15); % lambda_beta

% GMM_obj returns mean(moms,1)*W0, so we want W0 = eye(20) to return
% exactly the moments themselves.
W0 = eye(20);

% use lsqnonlin to calculate numerical jacobian            
[x,~,~,~,~,~,G] = lsqnonlin(@(x)GMM_obj(x, eta_sd, delta, W0, delta_mom),params_in,[],[],optimset('MaxIter',0));

csvwrite([tempfolder 'MATLAB_GS_jacobian.csv'],full(G));
csvwrite([tempfolder 'MATLAB_GS_wmatrix.csv'],W);
