function moms = moments( showup_hat, true_lambda, belief_lambda, induced_lambda, delta_mom )
%moments returns the full vector of moments (before taking means)
%   Detailed explanation goes here

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Moments:
% 1. mean showup rates in (measured) consumption quintiles in far and close subtreatment (separately). -> Ten moments
% 2. mean(showup-showuphat) of four extreme cells in grid of [tertiles of
% pmt * tertiles of w] (residual from the regression of log(consumption) on
% pmtscore) -> Four moments
% 3. two extreme cells in quartiles of distance -> Two moments
% 4. Lambda moments -> Four moments
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


global consumption showup close nquant;
global quant_idx quant_idx_pmt quant_idx_w quant_idx_dist;
global q_pmt_max q_pmt_min q_w_max q_w_min q_dist_max q_dist_min;

if isempty(consumption)
    error('Did not lead data before calling moments function');
end

% Store moments here
        N = size(consumption,1);
        moms = zeros(N, nquant*2+10);
        
        for i=1:5 % should be nquant, not 5, ideally
            
            % showup rates in far group by consuption quintile
            
            Ntemp =              sum(quant_idx==i & close==0);
            moms(:,i) =     showup.*(quant_idx==i & close==0)*N/Ntemp - ...
                        showup_hat.*(quant_idx==i & close==0)*N/Ntemp;
            
            % if delta_mom=1 we use the momserence between far and close (in
            % each quintile). If delta_mom=0 we use the showup mean in the
            % close consumption quintile
            
            Ntemp  =              sum(quant_idx==i & close==1);
            Ntemp0 =              sum(quant_idx==i & close==0);
            
            moms(:,5+i) =    showup.*(quant_idx==i & close==1)*N/Ntemp -...
                             showup.*(quant_idx==i & close==0)*N/Ntemp0*delta_mom  - ...
                         showup_hat.*(quant_idx==i & close==1)*N/Ntemp +...
                         showup_hat.*(quant_idx==i & close==0)*N/Ntemp0*delta_mom;
        end
        
        Ntemp =                     sum(quant_idx_pmt==q_pmt_max & quant_idx_w==q_w_min);
      moms(:,nquant*2+1) =     showup.*(quant_idx_pmt==q_pmt_max & quant_idx_w==q_w_min)*N/Ntemp - ...
                           showup_hat.*(quant_idx_pmt==q_pmt_max & quant_idx_w==q_w_min)*N/Ntemp;

        Ntemp =                     sum(quant_idx_pmt==q_pmt_max & quant_idx_w==q_w_max);
      moms(:,nquant*2+2) =     showup.*(quant_idx_pmt==q_pmt_max & quant_idx_w==q_w_max)*N/Ntemp - ...
                           showup_hat.*(quant_idx_pmt==q_pmt_max & quant_idx_w==q_w_max)*N/Ntemp;

        Ntemp =                     sum(quant_idx_pmt==q_pmt_min & quant_idx_w==q_w_min);
      moms(:,nquant*2+3) =     showup.*(quant_idx_pmt==q_pmt_min & quant_idx_w==q_w_min)*N/Ntemp - ...
                           showup_hat.*(quant_idx_pmt==q_pmt_min & quant_idx_w==q_w_min)*N/Ntemp;

        Ntemp =                     sum(quant_idx_pmt==q_pmt_min & quant_idx_w==q_w_max);
      moms(:,nquant*2+4) =     showup.*(quant_idx_pmt==q_pmt_min & quant_idx_w==q_w_max)*N/Ntemp - ...
                           showup_hat.*(quant_idx_pmt==q_pmt_min & quant_idx_w==q_w_max)*N/Ntemp;

        Ntemp =                     sum(quant_idx_dist==q_dist_max);
      moms(:,nquant*2+5) =     showup.*(quant_idx_dist==q_dist_max)*N/Ntemp - ...
                           showup_hat.*(quant_idx_dist==q_dist_max)*N/Ntemp;

        Ntemp =                     sum(quant_idx_dist==q_dist_min);
      moms(:,nquant*2+6) =     showup.*(quant_idx_dist==q_dist_min)*N/Ntemp - ...
                           showup_hat.*(quant_idx_dist==q_dist_min)*N/Ntemp;

      moms(:,nquant*2+7) = induced_lambda-belief_lambda;

      moms(:,nquant*2+8) = (induced_lambda-belief_lambda).*log(consumption);

      moms(:,nquant*2+9) = induced_lambda-true_lambda;

     moms(:,nquant*2+10) = (induced_lambda-true_lambda).*log(consumption);

        % if showup hat identically zero the lambda moments are NaN
        % replace with large number
        if max(isnan(moms))
            %y=10000000;
            error('isnan error reached');
            moms(isnan(moms))=10000;
        end

end

