function [ showup_hat, induced_lambda ] = showuphat(mu_eps, sig_eps, alpha, lambda_con_belief, lambda_beta_belief, eta_sd, delta)
%showuphat Calculate showuphat
%   use global data already in memory

global consumption totcost_pc benefit FE FE2 moneycost pmtscore;
global mu_con_true mu_beta_true

if isempty(consumption)
    error('Did not lead data before calling showuphat function');
end

        % convert mean and standard deviation into alpha and beta
        s = sqrt(3*(sig_eps.^2)./(pi.^2));
        alphaa = mu_eps./s;
        beta = 1./s;

        % Lower and upper bound, grid density for the numerical integration over eta
        lb = -eta_sd*4; ub = -lb;
        dense = 100;
        siz = size(consumption,1);

        %Prepare meshgrid
        eta = linspace(lb,ub,dense)';
        ETA = eta*ones(1,siz);
        Consumption = ones(dense,1)*(consumption');
        Pmtscore = ones(dense,1)*(pmtscore');
        Totcost_pc = ones(dense,1)*(totcost_pc');
        Benefit =  ones(dense,1)*(benefit');
        FFE2 = ones(dense,1)*(FE2');
        FFE  = ones(dense,1)*(FE');
        Moneycost = ones(dense,1)*(moneycost');

        %Calculate integrand
            %Present Utility (Cost function is adjusted because "totalcost" given is based on noisy consumption measure.)
            relu_2day = (Consumption.*exp(-ETA)-Totcost_pc.*exp(-ETA)+(1-1.*exp(-ETA)).*Moneycost)-(Consumption.*exp(-ETA));
            %Future Utility: note that normcdf() in the middle is mu function
            relu_2mor = (Consumption.*exp(-ETA)+Benefit)-(Consumption.*exp(-ETA)) ;

        
        Mu     = normcdf(mu_con_true+FFE2+mu_beta_true*(Pmtscore-ETA));
        Lambda = normcdf(lambda_con_belief+lambda_beta_belief*(log(Consumption)-ETA));

        prob_s = (1-1./(1+exp(beta.*(relu_2day + 12.*delta.*Mu    .*relu_2mor) + alphaa)));
        prob_u = (1-1./(1+exp(beta.*(relu_2day + 12.*delta.*Lambda.*relu_2mor) + alphaa)));   
  
        integ =(alpha*prob_s + (1-alpha)*prob_u ).*normpdf(ETA, 0, eta_sd);

        showup_hat = real(trapz(eta,integ)');

        % Rather than running probit, apply WLS.
        % Calculate inverse of mu Phi(-1)(mu) where Phi is standard normal CDF
        muinv = mu_con_true+FE2+mu_beta_true*(pmtscore);
        muinv_t = sqrt(showup_hat).*muinv; % Conversion for the frequency weight
        const_t = sqrt(showup_hat); % Conversion for the weight
        logcons_t = sqrt(showup_hat).*log(consumption); % Conversion for the weight
        X = [const_t, logcons_t];
        sigma2 = sqrt(sum(((eye(size(consumption,1))-X/(X'*X)*X')*muinv_t).^2)/(size(consumption,1)-2));
        coef = 1/sigma2*(X'*X)\X'*muinv_t; % Divide by sigma to impose sd = 1 for the error term
        induced_lambda = normcdf([ones(size(consumption)),log(consumption)]*coef); 

%         initial_lambda = normcdf(lambda_con_belief+lambda_beta_belief*log(consumption));
%         true_lambda    = normcdf(lambda_con_true+lambda_beta_true*log(consumption));

end

