
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% read and combine bootstrap results
% make table with empirical and simulated moments
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%clearvars -global

global t2folder
tempfolder = [t2folder 'data\codeddata\matlab\'];
    
% load full and original data 
sample=[];
small_sample_dummy=0;
load_data(sample,small_sample_dummy);

global consumption showup close nquant;
global quant_idx quant_idx_pmt quant_idx_w quant_idx_dist;
global q_pmt_max q_pmt_min q_w_max q_w_min q_dist_max q_dist_min;
global lambda_con_true lambda_beta_true
global getbenefit
if isempty(consumption)
    error('Did not load data');
end

eta_sd = 0.275;
delta_mom = 0;
irate = 1.22;
irm = 1/irate;
danual = 1/irate;
delta = danual*(1 + irm + irm^2 + irm^3 + irm^4 + irm^5);

% Input estimated parameters manually 
mu_eps        = -79678;	
sig_eps       = 59721;
alpha         = 0.5049;	
lambda_con_belief    = 8.0448;	
lambda_beta_belief   = -0.71673;

 [ showup_hat, induced_lambda ] = showuphat(mu_eps, sig_eps, alpha, lambda_con_belief, lambda_beta_belief, eta_sd, delta);

 belief_lambda  = normcdf(lambda_con_belief+lambda_beta_belief*log(consumption));
 true_lambda    = normcdf(lambda_con_true  +lambda_beta_true  *log(consumption));

 %moms = moments( showup_hat, true_lambda, belief_lambda, induced_lambda, delta_mom );


% Store moments here
        N = size(consumption,1);
        moms = zeros(2,N, nquant*2+10);
        
        for i=1:5 % should be nquant, not 5, ideally
            
            % showup rates in far group by consuption quintile
            
            Ntemp =              sum(quant_idx==i & close==0);
            moms(1,:,i) =     showup.*(quant_idx==i & close==0)*N/Ntemp;
            moms(2,:,i) = showup_hat.*(quant_idx==i & close==0)*N/Ntemp;
            
            % if delta_mom=1 we use the momserence between far and close (in
            % each quintile). If delta_mom=0 we use the showup mean in the
            % close consumption quintile
            
            Ntemp  =              sum(quant_idx==i & close==1);
            Ntemp0 =              sum(quant_idx==i & close==0);
            
            moms(1,:,5+i) =    showup.*(quant_idx==i & close==1)*N/Ntemp -...
                               showup.*(quant_idx==i & close==0)*N/Ntemp0*delta_mom;
            moms(2,:,5+i) =showup_hat.*(quant_idx==i & close==1)*N/Ntemp -...
                           showup_hat.*(quant_idx==i & close==0)*N/Ntemp0*delta_mom;
        end
        
        Ntemp =                     sum(quant_idx_pmt==q_pmt_max & quant_idx_w==q_w_min);
      moms(1,:,nquant*2+1) =     showup.*(quant_idx_pmt==q_pmt_max & quant_idx_w==q_w_min)*N/Ntemp;
      moms(2,:,nquant*2+1) = showup_hat.*(quant_idx_pmt==q_pmt_max & quant_idx_w==q_w_min)*N/Ntemp;

        Ntemp =                     sum(quant_idx_pmt==q_pmt_max & quant_idx_w==q_w_max);
      moms(1,:,nquant*2+2) =     showup.*(quant_idx_pmt==q_pmt_max & quant_idx_w==q_w_max)*N/Ntemp;
      moms(2,:,nquant*2+2) = showup_hat.*(quant_idx_pmt==q_pmt_max & quant_idx_w==q_w_max)*N/Ntemp;

        Ntemp =                     sum(quant_idx_pmt==q_pmt_min & quant_idx_w==q_w_min);
      moms(1,:,nquant*2+3) =     showup.*(quant_idx_pmt==q_pmt_min & quant_idx_w==q_w_min)*N/Ntemp;
      moms(2,:,nquant*2+3) = showup_hat.*(quant_idx_pmt==q_pmt_min & quant_idx_w==q_w_min)*N/Ntemp;

        Ntemp =                     sum(quant_idx_pmt==q_pmt_min & quant_idx_w==q_w_max);
      moms(1,:,nquant*2+4) =     showup.*(quant_idx_pmt==q_pmt_min & quant_idx_w==q_w_max)*N/Ntemp;
      moms(2,:,nquant*2+4) = showup_hat.*(quant_idx_pmt==q_pmt_min & quant_idx_w==q_w_max)*N/Ntemp;

        Ntemp =                     sum(quant_idx_dist==q_dist_max);
      moms(1,:,nquant*2+5) =     showup.*(quant_idx_dist==q_dist_max)*N/Ntemp;
      moms(2,:,nquant*2+5) = showup_hat.*(quant_idx_dist==q_dist_max)*N/Ntemp;

        Ntemp =                     sum(quant_idx_dist==q_dist_min);
      moms(1,:,nquant*2+6) =     showup.*(quant_idx_dist==q_dist_min)*N/Ntemp;
      moms(2,:,nquant*2+6) = showup_hat.*(quant_idx_dist==q_dist_min)*N/Ntemp;

      Ntemp = sum(showup==1);
  
      moms(1,:,nquant*2+7) =    getbenefit.*(showup==1)*N/Ntemp;
      moms(2,:,nquant*2+7) = belief_lambda.*(showup==1)*N/Ntemp;

      moms(1,:,nquant*2+8) =    getbenefit.*(log(consumption)-mean(log(consumption))).*(showup==1)*N/Ntemp;
      moms(2,:,nquant*2+8) = belief_lambda.*(log(consumption)-mean(log(consumption))).*(showup==1)*N/Ntemp;   

      moms(1,:,nquant*2+9) =     getbenefit.*(showup==1)*N/Ntemp;
      moms(2,:,nquant*2+9) = induced_lambda.*(showup==1)*N/Ntemp;

      moms(1,:,nquant*2+10) =     getbenefit.*(log(consumption)-mean(log(consumption))).*(showup==1)*N/Ntemp;
      moms(2,:,nquant*2+10) = induced_lambda.*(log(consumption)-mean(log(consumption))).*(showup==1)*N/Ntemp;

      moms = squeeze(mean(moms,2));
      
      moms(3,:)=moms(1,:)-moms(2,:);
 
csvwrite([tempfolder 'MATLAB_goodness_fit.csv'],moms');

